@@ -1,4 +1,4 @@
-# Copyright (C) 2023 - 2024 ANSYS, Inc. and/or its affiliates.
+# Copyright (C) 2023 - 2025 ANSYS, Inc. and/or its affiliates.
 # SPDX-License-Identifier: MIT
 #
 #
@@ -34,26 +34,32 @@ class Terminal(Connectable):
         self._reference_object = None
 
         self._boundary_type_mapping = {
-            "InvalidBoundary": self._pedb.core.cell.terminal.BoundaryType.InvalidBoundary,
-            "PortBoundary": self._pedb.core.cell.terminal.BoundaryType.PortBoundary,
-            "PecBoundary": self._pedb.core.cell.terminal.BoundaryType.PecBoundary,
-            "RlcBoundary": self._pedb.core.cell.terminal.BoundaryType.RlcBoundary,
-            "kCurrentSource": self._pedb.core.cell.terminal.BoundaryType.kCurrentSource,
-            "kVoltageSource": self._pedb.core.cell.terminal.BoundaryType.kVoltageSource,
-            "kNexximGround": self._pedb.core.cell.terminal.BoundaryType.kNexximGround,
-            "kNexximPort": self._pedb.core.cell.terminal.BoundaryType.kNexximPort,
-            "kDcTerminal": self._pedb.core.cell.terminal.BoundaryType.kDcTerminal,
-            "kVoltageProbe": self._pedb.core.cell.terminal.BoundaryType.kVoltageProbe,
+            "InvalidBoundary": self._pedb.core.Cell.Terminal.BoundaryType.InvalidBoundary,
+            "PortBoundary": self._pedb.core.Cell.Terminal.BoundaryType.PortBoundary,
+            "PecBoundary": self._pedb.core.Cell.Terminal.BoundaryType.PecBoundary,
+            "RlcBoundary": self._pedb.core.Cell.Terminal.BoundaryType.RlcBoundary,
+            "kCurrentSource": self._pedb.core.Cell.Terminal.BoundaryType.kCurrentSource,
+            "kVoltageSource": self._pedb.core.Cell.Terminal.BoundaryType.kVoltageSource,
+            "kNexximGround": self._pedb.core.Cell.Terminal.BoundaryType.kNexximGround,
+            "kNexximPort": self._pedb.core.Cell.Terminal.BoundaryType.kNexximPort,
+            "kDcTerminal": self._pedb.core.Cell.Terminal.BoundaryType.kDcTerminal,
+            "kVoltageProbe": self._pedb.core.Cell.Terminal.BoundaryType.kVoltageProbe,
         }
 
         self._terminal_type_mapping = {
-            "InvalidTerminal": self._pedb.core.cell.terminal.TerminalType.InvalidTerminal,
-            "EdgeTerminal": self._pedb.core.cell.terminal.TerminalType.EdgeTerminal,
-            "PointTerminal": self._pedb.core.cell.terminal.TerminalType.PointTerminal,
-            "TerminalInstanceTerminal": self._pedb.core.cell.terminal.TerminalType.TerminalInstanceTerminal,
-            "PadstackInstanceTerminal": self._pedb.core.cell.terminal.TerminalType.PadstackInstanceTerminal,
-            "BundleTerminal": self._pedb.core.cell.terminal.TerminalType.BundleTerminal,
-            "PinGroupTerminal": self._pedb.core.cell.terminal.TerminalType.PinGroupTerminal,
+            "InvalidTerminal": self._pedb.core.Cell.Terminal.TerminalType.InvalidTerminal,
+            "EdgeTerminal": self._pedb.core.Cell.Terminal.TerminalType.EdgeTerminal,
+            "PointTerminal": self._pedb.core.Cell.Terminal.TerminalType.PointTerminal,
+            "TerminalInstanceTerminal": self._pedb.core.Cell.Terminal.TerminalType.TerminalInstanceTerminal,
+            "PadstackInstanceTerminal": self._pedb.core.Cell.Terminal.TerminalType.PadstackInstanceTerminal,
+            "BundleTerminal": self._pedb.core.Cell.Terminal.TerminalType.BundleTerminal,
+            "PinGroupTerminal": self._pedb.core.Cell.Terminal.TerminalType.PinGroupTerminal,
+        }
+
+        self._source_term_to_ground_mapping = {
+            "kNoGround": self._pedb.core.Cell.Terminal.SourceTermToGround.kNoGround,
+            "kNegative": self._pedb.core.Cell.Terminal.SourceTermToGround.kNegative,
+            "kPositive": self._pedb.core.Cell.Terminal.SourceTermToGround.kPositive,
         }
 
     @property
@@ -240,10 +246,10 @@ class Terminal(Connectable):
         if not self._reference_object:
             term = self._edb_object
 
-            if self.terminal_type == self._pedb.core.cell.terminal.TerminalType.EdgeTerminal:
+            if self.terminal_type == self._pedb.core.Cell.Terminal.TerminalType.EdgeTerminal:
                 edges = self._edb_object.GetEdges()
                 edgeType = edges[0].GetEdgeType()
-                if edgeType == self._pedb.core.cell.terminal.EdgeType.PadEdge:
+                if edgeType == self._pedb.core.Cell.Terminal.EdgeType.PadEdge:
                     self._reference_object = self.get_pad_edge_terminal_reference_pin()
                 else:
                     self._reference_object = self.get_edge_terminal_reference_primitive()
@@ -304,14 +310,14 @@ class Terminal(Connectable):
         """
 
         refTerm = self._edb_object.GetReferenceTerminal()
-        if self._edb_object.GetTerminalType() == self._pedb.core.cell.terminal.TerminalType.PinGroupTerminal:
+        if self._edb_object.GetTerminalType() == self._pedb.core.Cell.Terminal.TerminalType.PinGroupTerminal:
             padStackInstance = self._edb_object.GetPinGroup().GetPins()[0]
             pingroup = refTerm.GetPinGroup()
             refPinList = pingroup.GetPins()
             return self._get_closest_pin(padStackInstance, refPinList, gnd_net_name_preference)
-        elif self._edb_object.GetTerminalType() == self._pedb.core.cell.terminal.TerminalType.PadstackInstanceTerminal:
+        elif self._edb_object.GetTerminalType() == self._pedb.core.Cell.Terminal.TerminalType.PadstackInstanceTerminal:
             _, padStackInstance, _ = self._edb_object.GetParameters()
-            if refTerm.GetTerminalType() == self._pedb.core.cell.terminal.TerminalType.PinGroupTerminal:
+            if refTerm.GetTerminalType() == self._pedb.core.Cell.Terminal.TerminalType.PinGroupTerminal:
                 pingroup = refTerm.GetPinGroup()
                 refPinList = pingroup.GetPins()
                 return self._get_closest_pin(padStackInstance, refPinList, gnd_net_name_preference)
@@ -403,6 +409,11 @@ class Terminal(Connectable):
             power_ground_net_names = [gnd_net]
         else:
             power_ground_net_names = [net for net in self._pedb.nets.power.keys()]
+        pin_list = [
+            EDBPadstackInstance(pin, self._pedb)
+            for pin in pin_list
+            if str(pin) == "Ansys.Ansoft.Edb.Cell.Primitive.PadstackInstance"
+        ]
         comp_ref_pins = [i for i in pin_list if i.net_name in power_ground_net_names]
         if len(comp_ref_pins) == 0:  # pragma: no cover
             self._pedb.logger.error(
@@ -425,7 +436,7 @@ class Terminal(Connectable):
                 closest_pin_distance = distance
                 pin_obj = pin
         if pin_obj:
-            return EDBPadstackInstance(pin_obj, self._pedb)
+            return pin_obj
 
     @property
     def magnitude(self):
@@ -434,7 +445,7 @@ class Terminal(Connectable):
 
     @magnitude.setter
     def magnitude(self, value):
-        self._edb_object.SetSourceAmplitude(self._edb.utility.value(value))
+        self._edb_object.SetSourceAmplitude(self._edb.Utility.Value(value))
 
     @property
     def phase(self):
@@ -443,4 +454,36 @@ class Terminal(Connectable):
 
     @phase.setter
     def phase(self, value):
-        self._edb_object.SetSourcePhase(self._edb.utility.value(value))
+        self._edb_object.SetSourcePhase(self._edb.Utility.Value(value))
+
+    @property
+    def amplitude(self):
+        """Property added for grpc compatibility"""
+        return self.magnitude
+
+    @property
+    def source_amplitude(self):
+        """Property added for grpc compatibility"""
+        return self.magnitude
+
+    @source_amplitude.setter
+    def source_amplitude(self, value):
+        self.magnitude = value
+
+    @property
+    def source_phase(self):
+        """Property added for grpc compatibility"""
+        return self.phase
+
+    @source_phase.setter
+    def source_phase(self, value):
+        self.phase = value
+
+    @property
+    def terminal_to_ground(self):
+        return self._edb_object.GetTerminalToGround().ToString()
+
+    @terminal_to_ground.setter
+    def terminal_to_ground(self, value):
+        obj = self._source_term_to_ground_mapping[value]
+        self._edb_object.SetTerminalToGround(obj)
