@@ -1,4 +1,4 @@
-# Copyright (C) 2023 - 2024 ANSYS, Inc. and/or its affiliates.
+# Copyright (C) 2023 - 2025 ANSYS, Inc. and/or its affiliates.
 # SPDX-License-Identifier: MIT
 #
 #
@@ -23,12 +23,14 @@
 import copy
 import os
 import re
-import subprocess
+import subprocess  # nosec B404
 import sys
 import xml
 
-from pyedb.edb_logger import pyedb_logger
+from defusedxml.ElementTree import parse as defused_parse
+
 from pyedb.generic.general_methods import ET, env_path, env_value, is_linux
+from pyedb.generic.settings import settings
 from pyedb.misc.aedtlib_personalib_install import write_pretty_xml
 from pyedb.misc.misc import list_installed_ansysem
 
@@ -36,6 +38,11 @@ from pyedb.misc.misc import list_installed_ansysem
 def convert_technology_file(tech_file, edbversion=None, control_file=None):
     """Convert a technology file to edb control file (xml).
 
+    .. warning::
+        Do not execute this function with untrusted function argument, environment
+        variables or pyedb global settings.
+        See the :ref:`security guide<ref_security_consideration>` for details.
+
     Parameters
     ----------
     tech_file : str
@@ -57,7 +64,7 @@ def convert_technology_file(tech_file, edbversion=None, control_file=None):
             base_path = env_path(edbversion)
             sys.path.append(base_path)
         else:
-            pyedb_logger.error("No Edb installation found. Check environment variables")
+            settings.logger.error("No Edb installation found. Check environment variables")
             return False
         os.environ["HELIC_ROOT"] = os.path.join(base_path, "helic")
         if os.getenv("ANSYSLMD_LICENCE_FILE", None) is None:
@@ -70,7 +77,7 @@ def convert_technology_file(tech_file, edbversion=None, control_file=None):
                             os.environ["ANSYSLMD_LICENSE_FILE"] = line.split("=")[1]
                             break
             else:
-                pyedb_logger.error("ANSYSLMD_LICENSE_FILE is not defined.")
+                settings.logger.error("ANSYSLMD_LICENSE_FILE is not defined.")
         vlc_file_name = os.path.splitext(tech_file)[0]
         if not control_file:
             control_file = vlc_file_name + ".xml"
@@ -99,14 +106,15 @@ def convert_technology_file(tech_file, edbversion=None, control_file=None):
         ]
         commands.append(command)
         commands.append(["rm", "-r", vlc_file_name + ".aedb"])
-        my_env = os.environ.copy()
         for command in commands:
-            p = subprocess.Popen(command, env=my_env)
-            p.wait()
+            try:
+                subprocess.run(command, check=True)  # nosec
+            except subprocess.CalledProcessError as e:  # nosec
+                raise RuntimeError("An error occurred while converting a technology file to edb control file") from e
         if os.path.exists(control_file):
-            pyedb_logger.info("Xml file created.")
+            settings.logger.info("Xml file created.")
             return control_file
-    pyedb_logger.error("Technology files are supported only in Linux. Use control file instead.")
+    settings.logger.error("Technology files are supported only in Linux. Use control file instead.")
     return False
 
 
@@ -123,7 +131,7 @@ class ControlProperty:
                 float(value)
                 self.type = 0
             except TypeError:
-                pass
+                self.type = -1
 
     def _write_xml(self, root):
         try:
@@ -133,8 +141,11 @@ class ControlProperty:
                 double.text = str(self.value)
             else:
                 pass
-        except:
-            pass
+        except Exception as e:
+            settings.logger.error(
+                f"A(n) {type(e).__name__} error occurred while attempting to create a new sub-element {self.name} "
+                f"for element {root}: {str(e)}"
+            )
 
 
 class ControlFileMaterial:
@@ -1210,7 +1221,7 @@ class ControlFile:
         -------
         bool
         """
-        tree = ET.parse(xml_input)
+        tree = defused_parse(xml_input)
         root = tree.getroot()
         for el in root:
             if el.tag == "Stackup":
