@@ -1,3 +1,25 @@
+# Copyright (C) 2023 - 2025 ANSYS, Inc. and/or its affiliates.
+# SPDX-License-Identifier: MIT
+#
+#
+# Permission is hereby granted, free of charge, to any person obtaining a copy
+# of this software and associated documentation files (the "Software"), to deal
+# in the Software without restriction, including without limitation the rights
+# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+# copies of the Software, and to permit persons to whom the Software is
+# furnished to do so, subject to the following conditions:
+#
+# The above copyright notice and this permission notice shall be included in all
+# copies or substantial portions of the Software.
+#
+# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+# SOFTWARE.
+
 from copy import deepcopy as copy
 import json
 from pathlib import Path
@@ -663,7 +685,7 @@ class ViaDesignBackend:
         pitch = self.cfg["general"]["pitch"]
 
         board = Board(
-            stackup=self.cfg["stackup"],
+            stackup=self.cfg["stackup"] if isinstance(self.cfg["stackup"], list) else self.cfg["stackup"]["layers"],
             padstack_defs=self.cfg["padstack_defs"],
             outline_extent=outline_extent,
             pitch=pitch,
@@ -673,9 +695,12 @@ class ViaDesignBackend:
         )
         board.populate_config(cfg_json)
 
+        self.output_dir.mkdir(parents=True, exist_ok=True)
+        with open(self.output_dir / "config.json", "w") as f:
+            json.dump(cfg_json, f, indent=4)
         self.app = Edb(
             edbpath=str((Path(self.output_dir) / self.cfg["title"]).with_suffix(".aedb")), edbversion=self.version
         )
         self.app.configuration.load(cfg_json, apply_file=True)
-        self.app.save_edb()
-        self.app.close_edb()
+        self.app.save()
+        self.app.close()
