@@ -1,4 +1,4 @@
-# Copyright (C) 2023 - 2024 ANSYS, Inc. and/or its affiliates.
+# Copyright (C) 2023 - 2025 ANSYS, Inc. and/or its affiliates.
 # SPDX-License-Identifier: MIT
 #
 #
@@ -35,15 +35,15 @@ import itertools
 import logging
 import math
 import os
-import random
 import re
+import secrets
 import string
 import sys
 import tempfile
 import time
 import traceback
+from typing import Dict
 
-from pyedb.exceptions import MaterialModelException
 from pyedb.generic.constants import CSS4_COLORS
 from pyedb.generic.settings import settings
 
@@ -51,13 +51,9 @@ is_linux = os.name == "posix"
 is_windows = not is_linux
 _pythonver = sys.version_info[0]
 
+import xml.etree.cElementTree as ET  # nosec B405
 
-try:
-    import xml.etree.cElementTree as ET
-
-    ET.VERSION
-except ImportError:
-    ET = None
+ET.VERSION
 
 
 class GrpcApiError(Exception):
@@ -119,7 +115,6 @@ def _exception(ex_info, func, args, kwargs, message="Type Error"):
     if message_to_print:
         _write_mes("Last Electronics Desktop Message - " + message_to_print)
 
-    args_name = []
     try:
         args_dict = _get_args_dicts(func, args, kwargs)
         first_time_log = True
@@ -130,91 +125,35 @@ def _exception(ex_info, func, args, kwargs, message="Type Error"):
                     _write_mes("Method arguments: ")
                     first_time_log = False
                 _write_mes("    {} = {} ".format(el, args_dict[el]))
-    except:
-        pass
-    args = [func.__name__] + [i for i in args_name if i not in ["self"]]
+    except Exception:
+        settings.logger.error(f"An error occurred while parsing and logging an error with method {func.__name__}.")
+
     if not func.__name__.startswith("_"):
         _write_mes(
             "Check Online documentation on: https://edb.docs.pyansys.com/version/stable/search.html?q={}".format(
-                "+".join(args)
+                func.__name__
             )
         )
 
 
-def _function_handler_wrapper(user_function):  # pragma: no cover
-    def wrapper(*args, **kwargs):  # pragma: no cover
-        if not settings.enable_error_handler:
-            result = user_function(*args, **kwargs)
-            return result
-        else:
-            try:
-                settings.time_tick = time.time()
-                out = user_function(*args, **kwargs)
-                if settings.enable_debug_logger or settings.enable_debug_edb_logger:
-                    _log_method(user_function, args, kwargs)
-                return out
-            except TypeError:
-                _exception(sys.exc_info(), user_function, args, kwargs, "Type Error")
-                return False
-            except ValueError:
-                _exception(sys.exc_info(), user_function, args, kwargs, "Value Error")
-                return False
-            except AttributeError:
-                _exception(sys.exc_info(), user_function, args, kwargs, "Attribute Error")
-                return False
-            except KeyError:
-                _exception(sys.exc_info(), user_function, args, kwargs, "Key Error")
-                return False
-            except IndexError:
-                _exception(sys.exc_info(), user_function, args, kwargs, "Index Error")
-                return False
-            except AssertionError:
-                _exception(sys.exc_info(), user_function, args, kwargs, "Assertion Error")
-                return False
-            except NameError:
-                _exception(sys.exc_info(), user_function, args, kwargs, "Name Error")
-                return False
-            except IOError:
-                _exception(sys.exc_info(), user_function, args, kwargs, "IO Error")
-                return False
-            except MaterialModelException:
-                _exception(sys.exc_info(), user_function, args, kwargs, "Material Model")
-                return False
+def installed_ansys_em_versions() -> Dict[str, str]:
+    """
+    Scan environment variables and return a dict
+    {version: installation_path} for every ANSYS EM release found.
+    Versions are ordered from oldest → latest (latest appears last).
+    """
+    pattern = re.compile(r"^ANSYSEM_ROOT(\d{3})$", re.IGNORECASE)
 
-    return wrapper
+    # collect everything
+    versions = {}
+    for key, value in os.environ.items():
+        m = pattern.match(key)
+        if m:
+            version = m.group(1)
+            versions[version] = value.rstrip(os.sep)
 
-
-import functools
-import warnings
-
-
-def deprecate_argument_name(argument_map):
-    """Decorator to deprecate certain argument names in favor of new ones."""
-
-    def decorator(func):
-        """Decorator that wraps the function to handle deprecated arguments."""
-
-        @functools.wraps(func)
-        def wrapper(*args, **kwargs):
-            """Wrapper function that checks for deprecated arguments."""
-            func_name = func.__name__
-            for old_arg, new_arg in argument_map.items():
-                if old_arg in kwargs:
-                    warnings.warn(
-                        f"Argument `{old_arg}` is deprecated for method `{func_name}`; use `{new_arg}` instead.",
-                        DeprecationWarning,
-                        stacklevel=2,
-                    )
-                    # NOTE: Use old argument if new argument is not provided
-                    if new_arg not in kwargs:
-                        kwargs[new_arg] = kwargs.pop(old_arg)
-                    else:
-                        kwargs.pop(old_arg)
-            return func(*args, **kwargs)
-
-        return wrapper
-
-    return decorator
+    # sort ascending so the latest is last
+    return dict(sorted(versions.items(), key=lambda kv: int(kv[0])))
 
 
 def get_filename_without_extension(path):
@@ -242,49 +181,6 @@ def _write_mes(mes_text):
         settings.logger.error(el)
 
 
-def _log_method(func, new_args, new_kwargs):  # pragma: no cover
-    if not settings.enable_debug_internal_methods_logger and str(func.__name__)[0] == "_":
-        return
-    if not settings.enable_debug_geometry_operator_logger and "GeometryOperators" in str(func):
-        return
-    if (
-        not settings.enable_debug_edb_logger
-        and "Edb" in str(func) + str(new_args)
-        or "database" in str(func) + str(new_args)
-    ):
-        return
-    line_begin = "ARGUMENTS: "
-    message = []
-    delta = time.time() - settings.time_tick
-    m, s = divmod(delta, 60)
-    h, m = divmod(m, 60)
-    d, h = divmod(h, 24)
-    msec = (s - int(s)) * 1000
-    if d > 0:
-        time_msg = " {}days {}h {}m {}sec.".format(d, h, m, int(s))
-    elif h > 0:
-        time_msg = " {}h {}m {}sec.".format(h, m, int(s))
-    else:
-        time_msg = "  {}m {}sec {}msec.".format(m, int(s), int(msec))
-    if settings.enable_debug_methods_argument_logger:
-        args_dict = _get_args_dicts(func, new_args, new_kwargs)
-        id = 0
-        if new_args:
-            object_name = str([new_args[0]])[1:-1]
-            id = object_name.find(" object at ")
-        if id > 0:
-            object_name = object_name[1:id]
-            message.append("'{}' was run in {}".format(object_name + "." + str(func.__name__), time_msg))
-        else:
-            message.append("'{}' was run in {}".format(str(func.__name__), time_msg))
-        message.append(line_begin)
-        for k, v in args_dict.items():
-            if k != "self":
-                message.append("    {} = {}".format(k, v))
-    for m in message:
-        settings.logger.debug(m)
-
-
 def _get_args_dicts(func, args, kwargs):
     if int(sys.version[0]) > 2:
         args_name = list(OrderedDict.fromkeys(inspect.getfullargspec(func)[0] + list(kwargs.keys())))
@@ -374,7 +270,7 @@ def generate_unique_name(rootname, suffix="", n=6):
 
     """
     char_set = string.ascii_uppercase + string.digits
-    uName = "".join(random.choice(char_set) for _ in range(n))
+    uName = "".join(secrets.choice(char_set) for _ in range(n))
     unique_name = rootname + "_" + uName
     if suffix:
         unique_name += "_" + suffix
@@ -815,13 +711,9 @@ def read_csv_pandas(filename, encoding="utf-8"):  # pragma: no cover
     :class:`pandas.DataFrame`
 
     """
-    try:
-        import pandas as pd
+    import pandas as pd
 
-        return pd.read_csv(filename, encoding=encoding, header=0, na_values=".")
-    except ImportError:
-        logging.error("Pandas is not available. Install it.")
-        return None
+    return pd.read_csv(filename, encoding=encoding, header=0, na_values=".")
 
 
 def read_tab(filename):  # pragma: no cover
@@ -855,14 +747,10 @@ def read_xlsx(filename):  # pragma: no cover
     list
 
     """
-    try:
-        import pandas as pd
+    import pandas as pd
 
-        lines = pd.read_excel(filename)
-        return lines
-    except ImportError:
-        lines = []
-        return lines
+    lines = pd.read_excel(filename)
+    return lines
 
 
 def write_csv(output, list_data, delimiter=",", quotechar="|", quoting=csv.QUOTE_MINIMAL):  # pragma: no cover
@@ -992,11 +880,7 @@ def compute_fft(time_vals, value):  # pragma: no cover
     tuple
         Frequency and Values.
     """
-    try:
-        import numpy as np
-    except ImportError:
-        logging.error("NumPy is not available. Install it.")
-        return False
+    import numpy as np
 
     deltaT = time_vals[-1] - time_vals[0]
     num_points = len(time_vals)
@@ -1045,11 +929,8 @@ def parse_excitation_file(
     tuple
         Frequency, magnitude and phase.
     """
-    try:
-        import numpy as np
-    except ImportError:
-        logging.error("NumPy is not available. Install it.")
-        return False
+    import numpy as np
+
     df = read_csv_pandas(file_name, encoding=encoding)
     if is_time_domain:
         time = df[df.keys()[0]].values * x_scale
@@ -1286,6 +1167,11 @@ def install_with_pip(package_name, package_path=None, upgrade=False, uninstall=F
     """Install a new package using pip.
     This method is useful for installing a package from the AEDT Console without launching the Python environment.
 
+    .. warning::
+        Do not execute this function with untrusted function argument, environment
+        variables or pyedb global settings.
+        See the :ref:`security guide<ref_security_consideration>` for details.
+
     Parameters
     ----------
     package_name : str
@@ -1298,10 +1184,12 @@ def install_with_pip(package_name, package_path=None, upgrade=False, uninstall=F
         Whether to install the package or uninstall the package.
     """
 
-    import subprocess
+    import subprocess  # nosec B404
 
-    executable = '"{}"'.format(sys.executable) if is_windows else sys.executable
+    if not package_name or not isinstance(package_name, str):
+        raise ValueError("A valid package name must be provided.")
 
+    executable = sys.executable
     commands = []
     if uninstall:
         commands.append([executable, "-m", "pip", "uninstall", "--yes", package_name])
@@ -1315,12 +1203,12 @@ def install_with_pip(package_name, package_path=None, upgrade=False, uninstall=F
             command.append("-U")
 
         commands.append(command)
+
     for command in commands:
-        if is_linux:
-            p = subprocess.Popen(command)
-        else:
-            p = subprocess.Popen(" ".join(command))
-        p.wait()
+        try:
+            subprocess.run(command, check=True)  # nosec
+        except subprocess.CalledProcessError as e:  # nosec
+            raise RuntimeError("An error occurred while installing with pip") from e
 
 
 class Help:  # pragma: no cover
