@@ -1,107 +1,142 @@
-import os.path
-import subprocess
+# Copyright (C) 2023 - 2025 ANSYS, Inc. and/or its affiliates.
+# SPDX-License-Identifier: MIT
+#
+#
+# Permission is hereby granted, free of charge, to any person obtaining a copy
+# of this software and associated documentation files (the "Software"), to deal
+# in the Software without restriction, including without limitation the rights
+# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+# copies of the Software, and to permit persons to whom the Software is
+# furnished to do so, subject to the following conditions:
+#
+# The above copyright notice and this permission notice shall be included in all
+# copies or substantial portions of the Software.
+#
+# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+# SOFTWARE.
 
-from pyedb.generic.general_methods import env_path, is_linux, is_windows
+import os.path
+from pathlib import Path
+import subprocess  # nosec B404
+
+from pyedb.generic.general_methods import is_linux
 
 
 class SiwaveSolve(object):
-    def __init__(self, aedb_path="", aedt_version="2021.2", aedt_installer_path=None):
-        self._project_path = aedb_path
-        self._exec_path = ""
-        self._nbcores = 4
-        self._ng = True
-        if aedt_installer_path:
-            self.installer_path = aedt_installer_path
-        else:
-            try:
-                self.installer_path = env_path(aedt_version)
-            except:
-                raise Exception("Either a valid aedt version or full path has to be provided")
-        if self._ng:
-            executable = "siwave_ng"
-        else:
-            executable = "siwave"
-        if is_linux:
-            self._exe = os.path.join(self.installer_path, executable)
-        else:
-            self._exe = os.path.join(self.installer_path, executable + ".exe")
+    def __init__(self, pedb):
+        self._pedb = pedb
 
     @property
-    def siwave_exe(self):
-        return self._exe
-
-    @siwave_exe.setter
-    def siwave_exe(self, value):
-        self._exe = value
+    def __siwave_exe_path(self):
+        executable = "siwave"
+        executable = executable if is_linux else executable + ".exe"
+        full_path = Path(self._pedb.ansys_em_path) / executable
+        return str(full_path)
 
     @property
-    def projectpath(self):
-        return self._project_path
+    def __siwave_ng_exe_path(self):
+        executable = "siwave_ng"
+        executable = executable if is_linux else executable + ".exe"
+        full_path = Path(self._pedb.ansys_em_path) / executable
+        return str(full_path)
 
-    @projectpath.setter
-    def projectpath(self, value):
-        self._project_path = value
+    def __create_exec(self, type):
+        base = os.path.splitext(self._pedb.edbpath)[0]
+        txt_path = base + ".txt"
+        exec_path = base + ".exec"
+        with open(txt_path, "w") as file:
+            if type:
+                if type == "DCIR":
+                    file.write("ExecDcSim")
+                elif type == "SYZ":
+                    file.write("ExecSyzSim")
+                elif type == "CPA":
+                    file.write("ExecSentinelCpaSim")
+                elif type == "TimeCrosstalk":
+                    file.write("ExecTimeDomainCrosstalkSim")
+                elif type == "FreqCrosstalk":
+                    file.write("ExecCrosstalkSim")
+                elif type == "Impedance":
+                    file.write("ExecZ0Sim")
 
-    @property
-    def execfile(self):
-        return self._exec_path
+        os.rename(txt_path, exec_path)
+        return exec_path
 
-    @execfile.setter
-    def execfile(self, value):
-        self._exec_path = value
+    def solve_siwave(self, edbpath, analysis_type):
+        """Solve an SIWave setup. Only non-graphical batch mode is supported.
 
-    @property
-    def nbcores(self):
-        return self._nbcores
+        .. warning::
+            Do not execute this function with untrusted function argument, environment
+            variables or pyedb global settings.
+            See the :ref:`security guide<ref_security_consideration>` for details.
 
-    @nbcores.setter
-    def nbcores(self, value):
-        self._nbcores = value
+        Parameters
+        ----------
+        analysis_type: str
+            Type of SIWave analysis to perform. Available types are "SYZ", "DCIR", "CPA", "TimeCrosstalk",
+            "FreqCrosstalk", "Impedance".
+        edbpath: str
+            Full path to the .aedb folder, siw or siwz file to be solved.
+        siwave_ng: str, optinial
+            Path to the siwave_ng. Default is the SIWave installation path.
+        """
 
-    @property
-    def nongraphical(self):
-        return self._ng
+        command = [
+            self.__siwave_ng_exe_path,
+            edbpath,
+            self.__create_exec(type=analysis_type),
+            "-formatOutput",
+            "-useSubdir",
+        ]
+        try:
+            subprocess.run(command, check=True)  # nosec
+        except subprocess.CalledProcessError as e:  # nosec
+            raise RuntimeError(f"An error occurred when launching the solver. Please check input paths") from e
 
-    @nongraphical.setter
-    def nongraphical(self, value):
-        self._ng = value
+    def solve(self, num_of_cores=4):
+        """Solve using siwave_ng.exe
 
-    def solve(self):
-        # supporting non graphical solve only
-        if self.nongraphical:
-            if is_linux:
-                exe_path = os.path.join(self.installer_path, "siwave_ng")
-            else:
-                exe_path = os.path.join(self.installer_path, "siwave_ng.exe")
-            exec_file = os.path.splitext(self._project_path)[0] + ".exec"
-            if os.path.exists(exec_file):
-                with open(exec_file, "r+") as f:
-                    content = f.readlines()
-                    if "SetNumCpus" not in content:
-                        f.writelines(str.format("SetNumCpus {}", str(self.nbcores)) + "\n")
-                        f.writelines("SaveSiw")
-                    else:
-                        fstarts = [i for i in range(len(content)) if content[i].startswith("SetNumCpus")]
-                        content[fstarts[0]] = str.format("SetNumCpus {}", str(self.nbcores))
-                        f.close()
-                        os.remove(exec_file)
-                        f = open(exec_file, "w")
-                        f.writelines(content)
-            command = [exe_path]
-            command.append(self._project_path)
-            command.append(exec_file)
-            command.append("-formatOutput -useSubdir")
-            if os.name == "posix":
-                p = subprocess.Popen(command)
-            else:
-                p = subprocess.Popen(" ".join(command))
-            p.wait()
+        .. warning::
+            Do not execute this function with untrusted function argument, environment
+            variables or pyedb global settings.
+            See the :ref:`security guide<ref_security_consideration>` for details.
+
+        """
+        exec_file = os.path.splitext(self._pedb.edbpath)[0] + ".exec"
+        if os.path.exists(exec_file):
+            with open(exec_file, "r+") as f:
+                content = f.readlines()
+                if "SetNumCpus" not in content:
+                    f.writelines(str.format("SetNumCpus {}", str(num_of_cores)) + "\n")
+                    f.writelines("SaveSiw")
+                else:
+                    fstarts = [i for i in range(len(content)) if content[i].startswith("SetNumCpus")]
+                    content[fstarts[0]] = str.format("SetNumCpus {}", str(num_of_cores))
+                    f.close()
+                    os.remove(exec_file)
+                    f = open(exec_file, "w")
+                    f.writelines(content)
+        command = [self.__siwave_ng_exe_path, self._pedb.edbpath, exec_file, "-formatOutput -useSubdir"]
+        try:
+            subprocess.run(command, check=True)  # nosec
+        except subprocess.CalledProcessError as e:  # nosec
+            raise RuntimeError("An error occurred while solving") from e
 
     def export_3d_cad(
-        self, format_3d="Q3D", output_folder=None, net_list=None, num_cores=None, aedt_file_name=None, hidden=False
+        self, format_3d="Q3D", output_folder=None, net_list=None, num_cores=4, aedt_file_name=None, hidden=False
     ):  # pragma: no cover
         """Export edb to Q3D or HFSS
 
+        .. warning::
+            Do not execute this function with untrusted function argument, environment
+            variables or pyedb global settings.
+            See the :ref:`security guide<ref_security_consideration>` for details.
+
         Parameters
         ----------
         format_3d : str, default ``Q3D``
@@ -119,11 +154,11 @@ class SiwaveSolve(object):
             path to aedt file
         """
         if not output_folder:
-            output_folder = os.path.dirname(self.projectpath)
+            output_folder = os.path.dirname(self._pedb.edbpath)
         scriptname = os.path.join(output_folder, "export_cad.py")
         with open(scriptname, "w") as f:
             f.write("import os\n")
-            f.write("edbpath = r'{}'\n".format(self.projectpath))
+            f.write("edbpath = r'{}'\n".format(self._pedb.edbpath))
             f.write("exportOptions = os.path.join(r'{}', 'options.config')\n".format(output_folder))
             f.write("oDoc.ScrImportEDB(edbpath)\n")
             f.write("oDoc.ScrSaveProjectAs(os.path.join(r'{}','{}'))\n".format(output_folder, "test.siw"))
@@ -140,23 +175,20 @@ class SiwaveSolve(object):
             f.write("q3d_filename = os.path.join(r'{}', '{}')\n".format(output_folder, aedt_file_name))
             if num_cores:
                 f.write("oDoc.ScrSetNumCpusToUse('{}')\n".format(num_cores))
-                self.nbcores = num_cores
             f.write("oDoc.ScrExport3DModel('{}', q3d_filename)\n".format(format_3d))
             f.write("oDoc.ScrCloseProject()\n")
             f.write("oApp.Quit()\n")
-        _exe = os.path.join(self.installer_path, "siwave")
-        if is_windows:
-            _exe += ".exe"
-        command = [_exe]
+
+        command = [self.__siwave_exe_path]
         if hidden:
             command.append("-embedding")
         command += ["-RunScriptAndExit", scriptname]
         print(command)
         try:
-            result = subprocess.run(command, check=True, capture_output=True)
+            result = subprocess.run(command, check=True, capture_output=True)  # nosec
             print(result.stdout.decode())
-        except subprocess.CalledProcessError as e:
-            print(f"Error occurred: {e.stderr.decode()}")
+        except subprocess.CalledProcessError as e:  # nosec
+            raise RuntimeError("An error occurred while exporting 3D CAD") from e
         return os.path.join(output_folder, aedt_file_name)
 
     def export_dc_report(
@@ -175,6 +207,11 @@ class SiwaveSolve(object):
     ):
         """Close EDB and solve it with Siwave.
 
+        .. warning::
+            Do not execute this function with untrusted function argument, environment
+            variables or pyedb global settings.
+            See the :ref:`security guide<ref_security_consideration>` for details.
+
         Parameters
         ----------
         siwave_project : str
@@ -204,7 +241,7 @@ class SiwaveSolve(object):
             list of files generated.
         """
         if not output_folder:
-            output_folder = os.path.dirname(self.projectpath)
+            output_folder = os.path.dirname(self._pedb.edbpath)
         output_list = []
         scriptname = os.path.normpath(os.path.join(os.path.normpath(output_folder), "export_results.py"))
         with open(scriptname, "w") as f:
@@ -265,20 +302,14 @@ class SiwaveSolve(object):
             f.write("proj.ScrCloseProject()\n")
 
             f.write("oApp.Quit()\n")
-        if is_linux:
-            _exe = '"' + os.path.join(self.installer_path, "siwave") + '"'
-        else:
-            _exe = '"' + os.path.join(self.installer_path, "siwave.exe") + '"'
-        command = [_exe]
+        command = [self.__siwave_exe_path]
         if hidden:
             command.append("-embedding")
         command.append("-RunScriptAndExit")
-        command.append('"' + scriptname + '"')
+        command.append(scriptname)
         print(command)
-        if os.name == "posix":
-            p = subprocess.Popen(command)
-
-        else:
-            p = subprocess.Popen(" ".join(command))
-        p.wait()
+        try:
+            subprocess.run(command, check=True)  # nosec
+        except subprocess.CalledProcessError as e:  # nosec
+            raise RuntimeError("An error occurred while solving with Siwave") from e
         return output_list
