@@ -1,4 +1,4 @@
-# Copyright (C) 2023 - 2024 ANSYS, Inc. and/or its affiliates.
+# Copyright (C) 2023 - 2025 ANSYS, Inc. and/or its affiliates.
 # SPDX-License-Identifier: MIT
 #
 #
@@ -20,9 +20,8 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 # SOFTWARE.
 
-"""This module contains the `Components` class.
+"""This module contains the `Components` class."""
 
-"""
 import codecs
 import json
 import math
@@ -31,8 +30,7 @@ import re
 from typing import Any, Dict, List, Optional, Tuple, Union
 import warnings
 
-from ansys.edb.core.definition.die_property import DieOrientation as GrpDieOrientation
-from ansys.edb.core.definition.die_property import DieType as GrpcDieType
+from ansys.edb.core.definition.die_property import DieOrientation as GrpDieOrientation, DieType as GrpcDieType
 from ansys.edb.core.definition.solder_ball_property import (
     SolderballShape as GrpcSolderballShape,
 )
@@ -57,6 +55,7 @@ from pyedb.grpc.database.hierarchy.pingroup import PinGroup
 from pyedb.grpc.database.padstacks import Padstacks
 from pyedb.grpc.database.utility.sources import SourceType
 from pyedb.grpc.database.utility.value import Value
+from pyedb.misc.decorators import deprecate_argument_name
 from pyedb.modeler.geometry_operators import GeometryOperators
 
 
@@ -500,6 +499,7 @@ class Components(object):
         """
         return self.instances[name]
 
+    @deprecate_argument_name({"pinName": "pin_name"})
     def get_pin_from_component(
         self,
         component: Union[str, Component],
@@ -994,8 +994,7 @@ class Components(object):
         """
         component_definition = ComponentDef.find(self._db, name)
         if component_definition.is_null:
-            from ansys.edb.core.layout.cell import Cell as GrpcCell
-            from ansys.edb.core.layout.cell import CellType as GrpcCellType
+            from ansys.edb.core.layout.cell import Cell as GrpcCell, CellType as GrpcCellType
 
             foot_print_cell = GrpcCell.create(self._pedb.active_db, GrpcCellType.FOOTPRINT_CELL, name)
             component_definition = ComponentDef.create(self._db, name, fp=foot_print_cell)
@@ -1011,8 +1010,6 @@ class Components(object):
                 if component_definition_pin.is_null:
                     self._logger.error(f"Failed to create component definition pin {name}-{pin.name}")
                     return None
-        else:
-            self._logger.warning("Found existing component definition for footprint {}".format(name))
         return component_definition
 
     def create(
@@ -1063,6 +1060,9 @@ class Components(object):
             ComponentGroup as GrpcComponentGroup,
         )
 
+        if not pins:
+            raise ValueError("Pins must be a list of PadstackInstance objects.")
+
         if not component_name:
             component_name = generate_unique_name("Comp_")
         if component_part_name:
@@ -1072,7 +1072,14 @@ class Components(object):
         if not compdef:
             return False
         new_cmp = GrpcComponentGroup.create(self._active_layout, component_name, compdef.name)
-        hosting_component_location = pins[0].component.transform
+        if new_cmp.is_null:
+            raise ValueError(f"Failed to create component {component_name}.")
+        if hasattr(pins[0], "component") and pins[0].component:
+            hosting_component_location = None
+            if not pins[0].component.is_null:
+                hosting_component_location = pins[0].component.transform
+        else:
+            hosting_component_location = None
         if not len(pins) == len(compdef.component_pins):
             self._pedb.logger.error(
                 f"Number on pins {len(pins)} does not match component definition number "
@@ -1090,7 +1097,18 @@ class Components(object):
         if new_cmp_layer_name in self._pedb.stackup.signal_layers:
             new_cmp_placement_layer = self._pedb.stackup.signal_layers[new_cmp_layer_name]
             new_cmp.placement_layer = new_cmp_placement_layer
-        new_cmp.component_type = GrpcComponentType.OTHER
+        if r_value:
+            new_cmp.component_type = GrpcComponentType.RESISTOR
+            is_rlc = True
+        elif c_value:
+            new_cmp.component_type = GrpcComponentType.CAPACITOR
+            is_rlc = True
+        elif l_value:
+            new_cmp.component_type = GrpcComponentType.INDUCTOR
+            is_rlc = True
+        else:
+            new_cmp.component_type = GrpcComponentType.OTHER
+            is_rlc = False
         if is_rlc and len(pins) == 2:
             rlc = GrpcRlc()
             rlc.is_parallel = is_parallel
@@ -1123,7 +1141,8 @@ class Components(object):
             component_property = new_cmp.component_property
             component_property.model = rlc_model
             new_cmp.component_property = component_property
-        new_cmp.transform = hosting_component_location
+        if hosting_component_location:
+            new_cmp.transform = hosting_component_location
         new_edb_comp = Component(self._pedb, new_cmp)
         self._cmp[new_cmp.name] = new_edb_comp
         return new_edb_comp
@@ -1309,13 +1328,14 @@ class Components(object):
         """
         deleted_comps = []
         for comp, val in self.instances.items():
-            if val.numpins < 2 and val.type in ["Resistor", "Capacitor", "Inductor"]:
-                if deactivate_only:
-                    val.is_enabled = False
-                    val.model_type = "RLC"
-                else:
-                    val.edbcomponent.delete()
-                    deleted_comps.append(comp)
+            if hasattr(val, "pins") and val.pins:
+                if val.num_pins == 1 and val.type in ["Resistor", "Capacitor", "Inductor"]:
+                    if deactivate_only:
+                        val.is_enabled = False
+                        val.model_type = "RLC"
+                    else:
+                        val.edbcomponent.delete()
+                        deleted_comps.append(comp)
         if not deactivate_only:
             self.refresh_components()
         self._pedb.logger.info("Deleted {} components".format(len(deleted_comps)))
@@ -1450,13 +1470,15 @@ class Components(object):
             sball_shape = GrpcSolderballShape.SOLDERBALL_SPHEROID
 
         cmp_property = cmp.component_property
-        if cmp.type == GrpcComponentType.IC:
+        if cmp.component_type == GrpcComponentType.IC:
             ic_die_prop = cmp_property.die_property
             ic_die_prop.die_type = GrpcDieType.FLIPCHIP
+            if not cmp.placement_layer == list(self._pedb.stackup.layers.keys())[0]:
+                chip_orientation = "chip_up"
             if chip_orientation.lower() == "chip_up":
-                ic_die_prop.orientation = GrpDieOrientation.CHIP_UP
+                ic_die_prop.die_orientation = GrpDieOrientation.CHIP_UP
             else:
-                ic_die_prop.orientation = GrpDieOrientation.CHIP_DOWN
+                ic_die_prop.die_orientation = GrpDieOrientation.CHIP_DOWN
             cmp_property.die_property = ic_die_prop
 
         solder_ball_prop = cmp_property.solder_ball_property
@@ -1664,7 +1686,9 @@ class Components(object):
                     if comp.partname == part_name:
                         pass
                     else:
-                        pinlist = self._pedb.padstacks.get_instances(refdes)
+                        pinlist = list(self.instances[refdes].pins.values())
+                        if not pinlist:
+                            continue
                         if not part_name in self.definitions:
                             comp_def = ComponentDef.create(self._db, part_name, None)
                             # for pin in range(len(pinlist)):
@@ -2206,7 +2230,7 @@ class Components(object):
         Examples
         --------
         >>> from pyedb import Edb
-        >>> edb_file = r'C:\my_edb_file.aedb'
+        >>> edb_file = r"C:\my_edb_file.aedb"
         >>> edb = Edb(edb_file)
         >>> for cmp in list(edb.components.instances.keys()):
         >>>     edb.components.deactivate_rlc_component(component=cmp, create_circuit_port=False)
