@@ -1,4 +1,4 @@
-# Copyright (C) 2023 - 2024 ANSYS, Inc. and/or its affiliates.
+# Copyright (C) 2023 - 2025 ANSYS, Inc. and/or its affiliates.
 # SPDX-License-Identifier: MIT
 #
 #
@@ -34,9 +34,9 @@ from ansys.edb.core.definition.djordjecvic_sarkar_model import (
     DjordjecvicSarkarModel as GrpcDjordjecvicSarkarModel,
 )
 from ansys.edb.core.definition.material_def import (
+    MaterialDef as GrpcMaterialDef,
     MaterialProperty as GrpcMaterialProperty,
 )
-from ansys.edb.core.definition.material_def import MaterialDef as GrpcMaterialDef
 from ansys.edb.core.definition.multipole_debye_model import (
     MultipoleDebyeModel as GrpcMultipoleDebyeModel,
 )
@@ -378,7 +378,7 @@ class Material(GrpcMaterialDef):
             "Use property dielectric_loss_tangent instead.",
             DeprecationWarning,
         )
-        self.dielectric_loss_tangent(value)
+        self.dielectric_loss_tangent = value
 
     @dielectric_loss_tangent.setter
     def dielectric_loss_tangent(self, value):
@@ -722,7 +722,7 @@ class Materials(object):
         :class:`Material <pyedb.grpc.database.definition.materials.Material>`
             Material object.
         """
-        extended_kwargs = {key: value for (key, value) in kwargs.items()}
+        extended_kwargs = {key: value for (key, value) in kwargs.items() if not key == "name"}
         extended_kwargs["permittivity"] = permittivity
         extended_kwargs["dielectric_loss_tangent"] = dielectric_loss_tangent
         material = self.add_material(name, **extended_kwargs)
