@@ -1,4 +1,4 @@
-# Copyright (C) 2023 - 2024 ANSYS, Inc. and/or its affiliates.
+# Copyright (C) 2023 - 2025 ANSYS, Inc. and/or its affiliates.
 # SPDX-License-Identifier: MIT
 #
 #
@@ -21,22 +21,21 @@
 # SOFTWARE.
 
 import math
+import warnings
 
 from ansys.edb.core.definition.padstack_def import PadstackDef as GrpcPadstackDef
 from ansys.edb.core.definition.padstack_def_data import (
     PadGeometryType as GrpcPadGeometryType,
-)
-from ansys.edb.core.definition.padstack_def_data import (
     PadstackHoleRange as GrpcPadstackHoleRange,
+    PadType as GrpcPadType,
 )
-from ansys.edb.core.definition.padstack_def_data import PadType as GrpcPadType
 import ansys.edb.core.geometry.polygon_data
 from ansys.edb.core.geometry.polygon_data import PolygonData as GrpcPolygonData
-from ansys.edb.core.hierarchy.structure3d import MeshClosure as GrpcMeshClosure
-from ansys.edb.core.hierarchy.structure3d import Structure3D as GrpcStructure3D
+from ansys.edb.core.hierarchy.structure3d import MeshClosure as GrpcMeshClosure, Structure3D as GrpcStructure3D
 from ansys.edb.core.primitive.circle import Circle as GrpcCircle
 
 from pyedb.generic.general_methods import generate_unique_name
+from pyedb.grpc.database.primitive.circle import Circle
 from pyedb.grpc.database.utility.value import Value
 
 
@@ -109,6 +108,26 @@ class PadProperties:
         """
         return self._pad_parameter_value[0].name.split("_")[-1].lower()
 
+    @shape.setter
+    def shape(self, value: str):
+        """Set pad shape.
+
+        Parameters
+        ----------
+        value : str
+            Pad shape.
+        """
+        if value.lower() == "circle":
+            self._update_pad_parameters_parameters(geom_type=GrpcPadGeometryType.PADGEOMTYPE_CIRCLE)
+        elif value.lower() == "rectangle":
+            self._update_pad_parameters_parameters(geom_type=GrpcPadGeometryType.PADGEOMTYPE_RECTANGLE)
+        elif value.lower() == "polygon":
+            self._update_pad_parameters_parameters(geom_type=GrpcPadGeometryType.PADGEOMTYPE_POLYGON)
+        else:
+            raise ValueError(
+                f"Unsupported pad shape: {value}. Supported shapes are 'circle', 'rectangle', and 'polygon'."
+            )
+
     @property
     def parameters_values(self):
         """Parameters.
@@ -276,7 +295,11 @@ class PadstackDef(GrpcPadstackDef):
         List[:class:`PadstackInstance <pyedb.grpc.database.primitive.padstack_instance.PadstackInstance>`]
             List of PadstackInstance objects.
         """
-        return [i for i in list(self._pedb.padstacks.instances.values()) if i.padstack_def.name == self.name]
+        return [
+            i
+            for i in list(self._pedb.padstacks.instances.values())
+            if not i.is_null and i.padstack_def.name == self.name
+        ]
 
     @property
     def layers(self) -> list[str]:
@@ -300,6 +323,22 @@ class PadstackDef(GrpcPadstackDef):
         """
         return self.layers[0]
 
+    @property
+    def via_start_layer(self):
+        """Via starting layer.
+
+        .deprecated
+        Use: :method:`start_layer <pyedb.grpc.database.definition.padstack_def.PadstackDef.start_layer>`
+        instead.
+
+        Returns
+        -------
+        str
+            Name of the via starting layer.
+        """
+        warnings.warn("via_start_layer is deprecated. Use start_layer instead.", DeprecationWarning)
+        return self.start_layer
+
     @property
     def stop_layer(self):
         """Stopping layer.
@@ -311,6 +350,38 @@ class PadstackDef(GrpcPadstackDef):
         """
         return self.layers[-1]
 
+    @property
+    def via_stop_layer(self):
+        """Via stop layer.
+
+        .deprecated
+        Use :method:`stop_layer <pyedb.grpc.database.definition.padstack_def.PadstackDef.stop_layer>`
+        instead.
+
+        Returns
+        -------
+        str
+            Name of the via stop layer.
+        """
+        warnings.warn("via_stop_layer is deprecated. Use stop_layer instead.", DeprecationWarning)
+        return self.stop_layer
+
+    @property
+    def material(self):
+        """Return hole material name.
+
+        Returns
+        -------
+        str
+            Hole material name.
+        """
+        return self.data.material.value
+
+    @material.setter
+    def material(self, value):
+        if isinstance(value, str):
+            self.data.material = value
+
     @property
     def hole_diameter(self) -> float:
         """Hole diameter.
@@ -592,15 +663,6 @@ class PadstackDef(GrpcPadstackDef):
             else:  # pragma no cover
                 self.data.hole_range = GrpcPadstackHoleRange.UNKNOWN_RANGE
 
-    @property
-    def material(self) -> str:
-        """Return hole material name."""
-        return self.data.material.value
-
-    @material.setter
-    def material(self, value):
-        self.data.material.value = value
-
     def convert_to_3d_microvias(
         self, convert_only_signal_vias=True, hole_wall_angle=15, delete_padstack_def=True
     ) -> bool:
@@ -667,7 +729,7 @@ class PadstackDef(GrpcPadstackDef):
                         net_name=via.net_name,
                     )
                 else:
-                    GrpcCircle.create(
+                    Circle(self._pedb).create(
                         layout,
                         self.start_layer,
                         via.net,
@@ -682,7 +744,7 @@ class PadstackDef(GrpcPadstackDef):
                         net_name=via.net_name,
                     )
                 else:
-                    GrpcCircle.create(
+                    Circle(self._pedb).create(
                         layout,
                         self.stop_layer,
                         via.net,
@@ -695,7 +757,7 @@ class PadstackDef(GrpcPadstackDef):
                     if layer_name == via.start_layer or started:
                         start = layer_name
                         stop = layer_names[layer_names.index(layer_name) + 1]
-                        cloned_circle = GrpcCircle.create(
+                        cloned_circle = Circle(self._pedb).create(
                             layout,
                             start,
                             via.net,
@@ -703,7 +765,7 @@ class PadstackDef(GrpcPadstackDef):
                             Value(pos[1]),
                             Value(rad1),
                         )
-                        cloned_circle2 = GrpcCircle.create(
+                        cloned_circle2 = Circle(self._pedb).create(
                             layout,
                             stop,
                             via.net,
@@ -718,7 +780,7 @@ class PadstackDef(GrpcPadstackDef):
                         s3d.add_member(cloned_circle2)
                         if not self.data.material.value:
                             self._pedb.logger.warning(
-                                f"Padstack definution {self.name} has no material defined." f"Defaulting to copper"
+                                f"Padstack definution {self.name} has no material defined.Defaulting to copper"
                             )
                             self.data.material = "copper"
                         s3d.set_material(self.data.material.value)
