@@ -1,4 +1,4 @@
-# Copyright (C) 2023 - 2024 ANSYS, Inc. and/or its affiliates.
+# Copyright (C) 2023 - 2025 ANSYS, Inc. and/or its affiliates.
 # SPDX-License-Identifier: MIT
 #
 #
@@ -28,14 +28,13 @@ import warnings
 from ansys.edb.core.definition.component_model import (
     NPortComponentModel as GrpcNPortComponentModel,
 )
-from ansys.edb.core.definition.die_property import DieOrientation as GrpcDieOrientation
-from ansys.edb.core.definition.die_property import DieType as GrpcDieType
+from ansys.edb.core.definition.die_property import DieOrientation as GrpcDieOrientation, DieType as GrpcDieType
 from ansys.edb.core.definition.solder_ball_property import SolderballShape
 from ansys.edb.core.geometry.polygon_data import PolygonData as GrpcPolygonData
 from ansys.edb.core.hierarchy.component_group import (
     ComponentGroup as GrpcComponentGroup,
+    ComponentType as GrpcComponentType,
 )
-from ansys.edb.core.hierarchy.component_group import ComponentType as GrpcComponentType
 from ansys.edb.core.hierarchy.netlist_model import NetlistModel as GrpcNetlistModel
 from ansys.edb.core.hierarchy.pin_pair_model import PinPairModel as GrpcPinPairModel
 from ansys.edb.core.hierarchy.sparameter_model import (
@@ -49,7 +48,9 @@ from ansys.edb.core.terminal.padstack_instance_terminal import (
     PadstackInstanceTerminal as GrpcPadstackInstanceTerminal,
 )
 from ansys.edb.core.utility.rlc import Rlc as GrpcRlc
+import numpy as np
 
+from pyedb.generic.general_methods import get_filename_without_extension
 from pyedb.grpc.database.hierarchy.pin_pair_model import PinPairModel
 from pyedb.grpc.database.hierarchy.s_parameter_model import SparamModel
 from pyedb.grpc.database.hierarchy.spice_model import SpiceModel
@@ -60,15 +61,6 @@ from pyedb.grpc.database.terminal.padstack_instance_terminal import (
 )
 from pyedb.grpc.database.utility.value import Value
 
-try:
-    import numpy as np
-except ImportError:
-    warnings.warn(
-        "The NumPy module is required to run some functionalities of EDB.\n"
-        "Install with \n\npip install numpy\n\nRequires CPython."
-    )
-from pyedb.generic.general_methods import get_filename_without_extension
-
 
 class Component(GrpcComponentGroup):
     """Manages EDB functionalities for components.
@@ -1102,7 +1094,7 @@ class Component(GrpcComponentGroup):
                 return False
         if not reference_net:
             self._pedb.logger.warning(
-                f"No reference net provided for S parameter file {file_path}, net `GND` is " f"assigned by default"
+                f"No reference net provided for S parameter file {file_path}, net `GND` is assigned by default"
             )
             reference_net = "GND"
         n_port_model = GrpcNPortComponentModel.find_by_name(self.component_def, name)
