@@ -1,4 +1,4 @@
-# Copyright (C) 2023 - 2024 ANSYS, Inc. and/or its affiliates.
+# Copyright (C) 2023 - 2025 ANSYS, Inc. and/or its affiliates.
 # SPDX-License-Identifier: MIT
 #
 #
@@ -23,8 +23,7 @@
 from __future__ import absolute_import
 
 from ansys.edb.core.layer.layer import LayerType as GrpcLayerType
-from ansys.edb.core.layer.stackup_layer import RoughnessRegion as GrpcRoughnessRegion
-from ansys.edb.core.layer.stackup_layer import StackupLayer as GrpcStackupLayer
+from ansys.edb.core.layer.stackup_layer import RoughnessRegion as GrpcRoughnessRegion, StackupLayer as GrpcStackupLayer
 
 from pyedb.grpc.database.utility.value import Value
 
@@ -354,8 +353,11 @@ class StackupLayer(GrpcStackupLayer):
             if len(top_roughness_model) == 2:
                 top_roughness_model[0] = Value(value)
                 self.set_roughness_model(top_roughness_model, GrpcRoughnessRegion.TOP)
-        except:
-            pass
+        except Exception as e:
+            self._pedb.logger.error(
+                f"Failed to update property top_hallhuray_nodule_radius with value {value} "
+                f"- {type(e).__name__}: {str(e)}"
+            )
 
     @property
     def top_hallhuray_surface_ratio(self) -> float:
@@ -382,8 +384,11 @@ class StackupLayer(GrpcStackupLayer):
             if len(top_roughness_model) == 2:
                 top_roughness_model[1] = Value(value)
                 self.set_roughness_model(top_roughness_model, GrpcRoughnessRegion.TOP)
-        except:
-            pass
+        except Exception as e:
+            self._pedb.logger.error(
+                f"Failed to update property top_hallhuray_surface_ratio with value {value} "
+                f"- {type(e).__name__}: {str(e)}"
+            )
 
     @property
     def bottom_hallhuray_nodule_radius(self) -> float:
@@ -410,8 +415,11 @@ class StackupLayer(GrpcStackupLayer):
             if len(bottom_roughness_model) == 2:
                 bottom_roughness_model[0] = Value(value)
                 self.set_roughness_model(bottom_roughness_model, GrpcRoughnessRegion.BOTTOM)
-        except:
-            pass
+        except Exception as e:
+            self._pedb.logger.error(
+                f"Failed to update property bottom_hallhuray_nodule_radius with value {value} "
+                f"- {type(e).__name__}: {str(e)}"
+            )
 
     @property
     def bottom_hallhuray_surface_ratio(self) -> float:
@@ -438,8 +446,11 @@ class StackupLayer(GrpcStackupLayer):
             if len(bottom_roughness_model) == 2:
                 bottom_roughness_model[1] = Value(value)
                 self.set_roughness_model(bottom_roughness_model, GrpcRoughnessRegion.BOTTOM)
-        except:
-            pass
+        except Exception as e:
+            self._pedb.logger.error(
+                f"Failed to update property bottom_hallhuray_surface_ratio with value {value} "
+                f"- {type(e).__name__}: {str(e)}"
+            )
 
     @property
     def side_hallhuray_nodule_radius(self) -> float:
@@ -466,8 +477,11 @@ class StackupLayer(GrpcStackupLayer):
             if len(side_roughness_model) == 2:
                 side_roughness_model[0] = Value(value)
                 self.set_roughness_model(side_roughness_model, GrpcRoughnessRegion.SIDE)
-        except:
-            pass
+        except Exception as e:
+            self._pedb.logger.error(
+                f"Failed to update property side_hallhuray_nodule_radius with value {value} "
+                f"- {type(e).__name__}: {str(e)}"
+            )
 
     @property
     def side_hallhuray_surface_ratio(self) -> float:
@@ -493,8 +507,11 @@ class StackupLayer(GrpcStackupLayer):
             if len(side_roughness_model) == 2:
                 side_roughness_model[1] = Value(value)
                 self.set_roughness_model(side_roughness_model, GrpcRoughnessRegion.SIDE)
-        except:
-            pass
+        except Exception as e:
+            self._pedb.logger.error(
+                f"Failed to update property side_hallhuray_surface_ratio with value {value} "
+                f"- {type(e).__name__}: {str(e)}"
+            )
 
     @property
     def top_groisse_roughness(self) -> float:
@@ -521,8 +538,10 @@ class StackupLayer(GrpcStackupLayer):
             if isinstance(top_roughness_model, Value):
                 top_roughness_model = Value(value)
                 self.set_roughness_model(top_roughness_model, GrpcRoughnessRegion.TOP)
-        except:
-            pass
+        except Exception as e:
+            self._pedb.logger.error(
+                f"Failed to update property top_groisse_roughness with value {value} - {type(e).__name__}: {str(e)}"
+            )
 
     @property
     def bottom_groisse_roughness(self) -> float:
@@ -549,8 +568,10 @@ class StackupLayer(GrpcStackupLayer):
             if isinstance(bottom_roughness_model, Value):
                 bottom_roughness_model = Value(value)
                 self.set_roughness_model(bottom_roughness_model, GrpcRoughnessRegion.BOTTOM)
-        except:
-            pass
+        except Exception as e:
+            self._pedb.logger.error(
+                f"Failed to update property bottom_groisse_roughness with value {value} - {type(e).__name__}: {str(e)}"
+            )
 
     @property
     def side_groisse_roughness(self) -> float:
@@ -578,7 +599,9 @@ class StackupLayer(GrpcStackupLayer):
                 side_roughness_model = Value(value)
                 self.set_roughness_model(side_roughness_model, GrpcRoughnessRegion.BOTTOM)
         except Exception as e:
-            self._pedb.logger.error(e)
+            self._pedb.logger.error(
+                f"Failed to update property side_groisse_roughness with value {value} - {type(e).__name__}: {str(e)}"
+            )
 
     def assign_roughness_model(
         self,
