@@ -1,4 +1,4 @@
-# Copyright (C) 2023 - 2024 ANSYS, Inc. and/or its affiliates.
+# Copyright (C) 2023 - 2025 ANSYS, Inc. and/or its affiliates.
 # SPDX-License-Identifier: MIT
 #
 #
@@ -25,9 +25,12 @@ from __future__ import absolute_import  # noreorder
 from typing import Any, Dict, List, Optional, Set, Tuple, Union
 import warnings
 
+from ansys.edb.core.net.net_class import NetClass as GrpcNetClass
+
 from pyedb.common.nets import CommonNets
 from pyedb.generic.general_methods import generate_unique_name
 from pyedb.grpc.database.net.net import Net
+from pyedb.grpc.database.net.net_class import NetClass
 from pyedb.grpc.database.primitive.bondwire import Bondwire
 from pyedb.grpc.database.primitive.path import Path
 from pyedb.grpc.database.primitive.polygon import Polygon
@@ -92,34 +95,21 @@ class Nets(CommonNets):
     >>> print("Eligible power nets:", [net.name for net in eligible_pwr])
 
     >>> # Generate extended nets (deprecated)
-    >>> nets.generate_extended_nets(
-    >>> resistor_below=5,
-    >>>inductor_below=0.5,
-    >>> capacitor_above=0.1
-    >>> )
+    >>> nets.generate_extended_nets(resistor_below=5, inductor_below=0.5, capacitor_above=0.1)
 
     >>> # Classify nets
-    >>> nets.classify_nets(
-    >>> power_nets=["VDD_CPU", "VDD_MEM"],
-    >>> signal_nets=["PCIe_TX", "ETH_RX"]
-    >>> )
+    >>> nets.classify_nets(power_nets=["VDD_CPU", "VDD_MEM"], signal_nets=["PCIe_TX", "ETH_RX"])
 
     >>> # Check power/ground status
     >>> is_power = nets.is_power_gound_net(["VDD_CPU", "PCIe_TX"])
     >>> print("Is power net:", is_power)
 
     >>> # Get DC-connected nets
-    >>> dc_connected = nets.get_dcconnected_net_list(
-    >>> ground_nets=["GND"],
-    >>> res_value=0.002
-    >>> )
+    >>> dc_connected = nets.get_dcconnected_net_list(ground_nets=["GND"], res_value=0.002)
         print("DC-connected nets:", dc_connected)
 
     >>> # Get power tree
-    >>> comp_list, columns, net_group = nets.get_powertree(
-    >>> power_net_name="VDD_CPU",
-    >>> ground_nets=["GND"]
-    >>> )
+    >>> comp_list, columns, net_group = nets.get_powertree(power_net_name="VDD_CPU", ground_nets=["GND"])
     >>> print("Power tree components:", comp_list)
 
     >>> # Find net by name
@@ -139,10 +129,7 @@ class Nets(CommonNets):
     >>> print("Net in component:", in_component)
 
     >>> # Find and fix disjoint nets (deprecated)
-    >>> fixed_nets = nets.find_and_fix_disjoint_nets(
-    >>> net_list=["PCIe_TX"],
-    >>> clean_disjoints_less_than=1e-6
-    >>> )
+    >>> fixed_nets = nets.find_and_fix_disjoint_nets(net_list=["PCIe_TX"], clean_disjoints_less_than=1e-6)
     >>> print("Fixed nets:", fixed_nets)
 
     >>> # Merge net polygons
@@ -419,11 +406,7 @@ class Nets(CommonNets):
 
         Examples
         --------
-        >>> edb_nets.generate_extended_nets(
-        ...     resistor_below=5,
-        ...     inductor_below=0.5,
-        ...     capacitor_above=0.1
-        ... )
+        >>> edb_nets.generate_extended_nets(resistor_below=5, inductor_below=0.5, capacitor_above=0.1)
         """
         warnings.warn("Use new method :func:`edb.extended_nets.generate_extended_nets` instead.", DeprecationWarning)
         self._pedb.extended_nets.generate_extended_nets(
@@ -484,10 +467,7 @@ class Nets(CommonNets):
 
         Examples
         --------
-        >>> edb_nets.classify_nets(
-        ...     power_nets=["VDD_CPU", "VDD_MEM"],
-        ...     signal_nets=["PCIe_TX", "ETH_RX"]
-        ... )
+        >>> edb_nets.classify_nets(power_nets=["VDD_CPU", "VDD_MEM"], signal_nets=["PCIe_TX", "ETH_RX"])
         """
         if isinstance(power_nets, str):
             power_nets = []
@@ -548,10 +528,7 @@ class Nets(CommonNets):
 
         Examples
         --------
-        >>> dc_connected = edb_nets.get_dcconnected_net_list(
-        ...     ground_nets=["GND"],
-        ...     res_value=0.002
-        ... )
+        >>> dc_connected = edb_nets.get_dcconnected_net_list(ground_nets=["GND"], res_value=0.002)
         >>> for net_group in dc_connected:
         ...     print("Connected nets:", net_group)
         """
@@ -608,10 +585,7 @@ class Nets(CommonNets):
 
         Examples
         --------
-        >>> comp_list, columns, net_group = edb_nets.get_powertree(
-        ...     power_net_name="VDD_CPU",
-        ...     ground_nets=["GND"]
-        ... )
+        >>> comp_list, columns, net_group = edb_nets.get_powertree(power_net_name="VDD_CPU", ground_nets=["GND"])
         >>> print("Power tree components:", comp_list)
         """
         flag_in_ng = False
@@ -697,7 +671,7 @@ class Nets(CommonNets):
 
         Examples
         --------
-        >>> deleted_nets = database.nets.delete(["Net1","Net2"])
+        >>> deleted_nets = database.nets.delete(["Net1", "Net2"])
         """
         if isinstance(netlist, str):
             netlist = [netlist]
@@ -855,10 +829,7 @@ class Nets(CommonNets):
 
         Examples
         --------
-        >>> fixed_nets = edb_nets.find_and_fix_disjoint_nets(
-        ...     net_list=["PCIe_TX"],
-        ...     clean_disjoints_less_than=1e-6
-        ... )
+        >>> fixed_nets = edb_nets.find_and_fix_disjoint_nets(net_list=["PCIe_TX"], clean_disjoints_less_than=1e-6)
         >>> print("Fixed nets:", fixed_nets)
         """
 
@@ -888,3 +859,70 @@ class Nets(CommonNets):
         if isinstance(net_names_list, str):
             net_names_list = [net_names_list]
         return self._pedb.modeler.unite_polygons_on_layer(net_names_list=net_names_list)
+
+
+class NetClasses:
+    """Net classes management.
+
+    This class provides access to net classes in the EDB layout.
+    It allows for operations like retrieving nets, adding/removing nets,
+    and checking if a net is part of a net class.
+
+    Examples
+    --------
+    >>> from pyedb import Edb
+    >>> edb = Edb(myedb, edbversion="2025.1")
+    >>> net_classes = edb.net_classes
+    """
+
+    def __init__(self, pedb):
+        self._pedb = pedb
+        self._net_classes = pedb.active_layout.net_classes
+
+    def __getitem__(self, name: str) -> NetClass:
+        """Get a net by name.
+
+        Parameters
+        ----------
+        name : str
+            Name of the net to retrieve.
+
+        """
+        return self.items[name]
+
+    @property
+    def items(self) -> Dict[str, NetClass]:
+        """Extended nets.
+
+        Returns
+        -------
+        Dict[str, :class:`pyedb.grpc.database.nets.nets_class.NetClass`]
+            Dictionary of extended nets.
+        """
+        return {i.name: i for i in self._pedb.layout.net_classes}
+
+    def create(self, name, net) -> Union[bool, NetClass]:
+        """Create a new net class.
+
+        Parameters
+        ----------
+        name : str
+            Name of the net class.
+        net : str, list
+           Name of the nets to be added into this net class.
+
+        Returns
+        -------
+        :class:`pyedb.dotnet.database.edb_data.nets_data.EDBNetClassData` `False` if net name already exists.
+        """
+        if name in self.items:
+            self._pedb.logger.error("{} already exists.".format(name))
+            return False
+        grpc_net_class = GrpcNetClass.create(self._pedb.active_layout, name)
+        if isinstance(net, str):
+            net = [net]
+        for i in net:
+            grpc_net_class.add_net(self._pedb.nets[i])
+        net_class = NetClass(self._pedb, grpc_net_class)
+        self.items[name] = net_class
+        return net_class
