@@ -1,4 +1,4 @@
-# Copyright (C) 2023 - 2024 ANSYS, Inc. and/or its affiliates.
+# Copyright (C) 2023 - 2025 ANSYS, Inc. and/or its affiliates.
 # SPDX-License-Identifier: MIT
 #
 #
@@ -23,27 +23,21 @@
 """
 This module contains the `EdbPadstacks` class.
 """
+
 from collections import defaultdict
+from functools import lru_cache
 import math
 from typing import Any, Dict, List, Optional, Tuple, Union
 import warnings
 
 from ansys.edb.core.definition.padstack_def_data import (
     PadGeometryType as GrpcPadGeometryType,
-)
-from ansys.edb.core.definition.padstack_def_data import (
     PadstackDefData as GrpcPadstackDefData,
-)
-from ansys.edb.core.definition.padstack_def_data import (
     PadstackHoleRange as GrpcPadstackHoleRange,
-)
-from ansys.edb.core.definition.padstack_def_data import (
+    PadType as GrpcPadType,
     SolderballPlacement as GrpcSolderballPlacement,
-)
-from ansys.edb.core.definition.padstack_def_data import (
     SolderballShape as GrpcSolderballShape,
 )
-from ansys.edb.core.definition.padstack_def_data import PadType as GrpcPadType
 from ansys.edb.core.geometry.point_data import PointData as GrpcPointData
 from ansys.edb.core.geometry.polygon_data import PolygonData as GrpcPolygonData
 import numpy as np
@@ -55,6 +49,29 @@ from pyedb.grpc.database.primitive.padstack_instance import PadstackInstance
 from pyedb.grpc.database.utility.value import Value
 from pyedb.modeler.geometry_operators import GeometryOperators
 
+GEOMETRY_MAP = {
+    0: GrpcPadGeometryType.PADGEOMTYPE_NO_GEOMETRY,
+    1: GrpcPadGeometryType.PADGEOMTYPE_CIRCLE,
+    2: GrpcPadGeometryType.PADGEOMTYPE_SQUARE,
+    3: GrpcPadGeometryType.PADGEOMTYPE_RECTANGLE,
+    4: GrpcPadGeometryType.PADGEOMTYPE_OVAL,
+    5: GrpcPadGeometryType.PADGEOMTYPE_BULLET,
+    6: GrpcPadGeometryType.PADGEOMTYPE_NSIDED_POLYGON,
+    7: GrpcPadGeometryType.PADGEOMTYPE_POLYGON,
+    8: GrpcPadGeometryType.PADGEOMTYPE_ROUND45,
+    9: GrpcPadGeometryType.PADGEOMTYPE_ROUND90,
+    10: GrpcPadGeometryType.PADGEOMTYPE_SQUARE45,
+    11: GrpcPadGeometryType.PADGEOMTYPE_SQUARE90,
+}
+
+PAD_TYPE_MAP = {
+    0: GrpcPadType.REGULAR_PAD,
+    1: GrpcPadType.ANTI_PAD,
+    2: GrpcPadType.THERMAL_PAD,
+    3: GrpcPadType.HOLE,
+    4: GrpcPadType.UNKNOWN_GEOM_TYPE,
+}
+
 
 class Padstacks(object):
     """Manages EDB methods for padstacks accessible from `Edb.padstacks` property.
@@ -93,8 +110,16 @@ class Padstacks(object):
 
     def __init__(self, p_edb: Any) -> None:
         self._pedb = p_edb
-        self._instances: Dict[int, PadstackInstance] = {}
-        self._definitions: Dict[str, Any] = {}
+        self.__definitions: Dict[str, Any] = {}
+        self._instances = None
+        self._instances_by_name = {}
+        self._instances_by_net = {}
+
+    def clear_instances_cache(self):
+        """Clear the cached padstack instances."""
+        self._instances = None
+        self._instances_by_name = {}
+        self._instances_by_net = {}
 
     @property
     def _active_layout(self) -> Any:
@@ -121,7 +146,8 @@ class Padstacks(object):
         """ """
         return self._pedb.stackup.layers
 
-    def int_to_pad_type(self, val=0) -> GrpcPadType:
+    @staticmethod
+    def int_to_pad_type(val=0) -> GrpcPadType:
         """Convert an integer to an EDB.PadGeometryType.
 
         Parameters
@@ -139,20 +165,10 @@ class Padstacks(object):
         >>> pad_type = edb_padstacks.int_to_pad_type(1)  # Returns ANTI_PAD
         """
 
-        if val == 0:
-            return GrpcPadType.REGULAR_PAD
-        elif val == 1:
-            return GrpcPadType.ANTI_PAD
-        elif val == 2:
-            return GrpcPadType.THERMAL_PAD
-        elif val == 3:
-            return GrpcPadType.HOLE
-        elif val == 4:
-            return GrpcPadType.UNKNOWN_GEOM_TYPE
-        else:
-            return val
+        return PAD_TYPE_MAP.get(val, val)
 
-    def int_to_geometry_type(self, val: int = 0) -> GrpcPadGeometryType:
+    @staticmethod
+    def int_to_geometry_type(val: int = 0) -> GrpcPadGeometryType:
         """Convert an integer to an EDB.PadGeometryType.
 
         Parameters
@@ -169,32 +185,7 @@ class Padstacks(object):
         >>> geom_type = edb_padstacks.int_to_geometry_type(1)  # Returns CIRCLE
         >>> geom_type = edb_padstacks.int_to_geometry_type(2)  # Returns SQUARE
         """
-        if val == 0:
-            return GrpcPadGeometryType.PADGEOMTYPE_NO_GEOMETRY
-        elif val == 1:
-            return GrpcPadGeometryType.PADGEOMTYPE_CIRCLE
-        elif val == 2:
-            return GrpcPadGeometryType.PADGEOMTYPE_SQUARE
-        elif val == 3:
-            return GrpcPadGeometryType.PADGEOMTYPE_RECTANGLE
-        elif val == 4:
-            return GrpcPadGeometryType.PADGEOMTYPE_OVAL
-        elif val == 5:
-            return GrpcPadGeometryType.PADGEOMTYPE_BULLET
-        elif val == 6:
-            return GrpcPadGeometryType.PADGEOMTYPE_NSIDED_POLYGON
-        elif val == 7:
-            return GrpcPadGeometryType.PADGEOMTYPE_POLYGON
-        elif val == 8:
-            return GrpcPadGeometryType.PADGEOMTYPE_ROUND45
-        elif val == 9:
-            return GrpcPadGeometryType.PADGEOMTYPE_ROUND90
-        elif val == 10:
-            return GrpcPadGeometryType.PADGEOMTYPE_SQUARE45
-        elif val == 11:
-            return GrpcPadGeometryType.PADGEOMTYPE_SQUARE90
-        else:
-            return val
+        return GEOMETRY_MAP.get(val, val)
 
     @property
     def definitions(self) -> Dict[str, PadstackDef]:
@@ -211,13 +202,12 @@ class Padstacks(object):
         >>> for name, definition in all_definitions.items():
         ...     print(f"Padstack: {name}")
         """
-        if len(self._definitions) == len(self.db.padstack_defs):
-            return self._definitions
-        self._definitions = {}
-        for padstack_def in self._pedb.db.padstack_defs:
+        padstack_defs = self._pedb.db.padstack_defs
+        self.__definitions = {}
+        for padstack_def in padstack_defs:
             if len(padstack_def.data.layer_names) >= 1:
-                self._definitions[padstack_def.name] = PadstackDef(self._pedb, padstack_def)
-        return self._definitions
+                self.__definitions[padstack_def.name] = PadstackDef(self._pedb, padstack_def)
+        return self.__definitions
 
     @property
     def instances(self) -> Dict[int, PadstackInstance]:
@@ -230,16 +220,22 @@ class Padstacks(object):
 
         Examples
         --------
-        >>> all_instances = edb_padstacks.instances
+        >>> all_instances = edb.padstacks.instances
         >>> for id, instance in all_instances.items():
         ...     print(f"Instance {id}: {instance.name}")
         """
-        pad_stack_inst = self._pedb.layout.padstack_instances
-        if len(self._instances) == len(pad_stack_inst):
-            return self._instances
-        self._instances = {i.edb_uid: PadstackInstance(self._pedb, i) for i in pad_stack_inst}
+        if self._instances is None:
+            self._instances = self._pedb.layout.padstack_instances
         return self._instances
 
+    @property
+    def instances_by_net(self) -> Dict[Any, PadstackInstance]:
+        if not self._instances_by_net:
+            for edb_padstack_instance in self.instances.values():
+                if edb_padstack_instance.net_name:
+                    self._instances_by_net.setdefault(edb_padstack_instance.net_name, []).append(edb_padstack_instance)
+        return self._instances_by_net
+
     @property
     def instances_by_name(self) -> Dict[str, PadstackInstance]:
         """All padstack instances (vias and pins) indexed by name.
@@ -255,11 +251,11 @@ class Padstacks(object):
         >>> for name, instance in named_instances.items():
         ...     print(f"Instance named {name}")
         """
-        padstack_instances = {}
-        for _, edb_padstack_instance in self.instances.items():
-            if edb_padstack_instance.aedt_name:
-                padstack_instances[edb_padstack_instance.aedt_name] = edb_padstack_instance
-        return padstack_instances
+        if not self._instances_by_name:
+            for _, edb_padstack_instance in self.instances.items():
+                if edb_padstack_instance.aedt_name:
+                    self._instances_by_name[edb_padstack_instance.aedt_name] = edb_padstack_instance
+        return self._instances_by_name
 
     def find_instance_by_id(self, value: int) -> Optional[PadstackInstance]:
         """Find a padstack instance by database ID.
@@ -340,7 +336,7 @@ class Padstacks(object):
         >>> groups = edb_padstacks._layout.pin_groups  # New way
         """
         warnings.warn(
-            "`pingroups` is deprecated and is now located here " "`pyedb.grpc.core.layout.pin_groups` instead.",
+            "`pingroups` is deprecated and is now located here `pyedb.grpc.core.layout.pin_groups` instead.",
             DeprecationWarning,
         )
         return self._layout.pin_groups
@@ -348,6 +344,189 @@ class Padstacks(object):
     @property
     def pad_type(self) -> GrpcPadType:
         """Return a PadType Enumerator."""
+        return GrpcPadType
+
+    def create_dielectric_filled_backdrills(
+        self,
+        layer: str,
+        diameter: Union[float, str],
+        material: str,
+        permittivity: float,
+        padstack_instances: Optional[List[PadstackInstance]] = None,
+        padstack_definition: Optional[Union[str, List[str]]] = None,
+        dielectric_loss_tangent: Optional[float] = None,
+        nets: Optional[Union[str, List[str]]] = None,
+    ) -> bool:
+        r"""Create dielectric-filled back-drills for through-hole vias.
+
+        Back-drilling (a.k.a. controlled-depth drilling) is used to remove the
+        unused via stub that acts as an unterminated transmission-line segment,
+        thereby improving signal-integrity at high frequencies.  This routine
+        goes one step further: after the stub is removed the resulting cylindrical
+        cavity is **completely filled** with a user-specified dielectric.  The
+        fill material restores mechanical rigidity, prevents solder-wicking, and
+        keeps the original via’s electrical characteristics intact on the
+        remaining, still-plated, portion.
+
+        Selection criteria
+        ------------------
+        A via is processed only when **all** of the following are true:
+
+        1. It is a through-hole structure (spans at least three metal layers).
+        2. It includes the requested ``layer`` somewhere in its layer span.
+        3. It belongs to one of the supplied ``padstack_definition`` names
+           (or to *any* definition if the argument is omitted).
+        4. It is attached to one of the supplied ``nets`` (or to *any* net if
+           the argument is omitted).
+
+        Geometry that is created
+        ------------------------
+        For every qualified via the routine
+
+        * Generates a new pad-stack definition named ``<original_name>_BD``.
+          The definition is drilled from the **bottom-most signal layer** up to
+          and **including** ``layer``, uses the exact ``diameter`` supplied, and
+          is plated at 100 %.
+        * Places an additional pad-stack instance on top of the original via,
+          thereby filling the newly drilled cavity with the requested
+          ``material``.
+        * Leaves the original via untouched—only its unused stub is removed.
+
+        The back-drill is **not** subtracted from anti-pads or plane clearances;
+        the filling material is assumed to be electrically invisible at the
+        frequencies of interest.
+
+        Parameters
+        ----------
+        layer : :class:`str`
+            Signal layer name up to which the back-drill is performed (inclusive).
+            The drill always starts on the bottom-most signal layer of the stack-up.
+        diameter : :class:`float` or :class:`str`
+            Finished hole diameter for the back-drill.  A numeric value is
+            interpreted in the database length unit; a string such as
+            ``"0.3mm"`` is evaluated with units.
+        material : :class:`str`
+            Name of the dielectric material that fills the drilled cavity.  If the
+            material does not yet exist in the central material library it is
+            created on the fly.
+        permittivity : :class:`float`
+            Relative permittivity :math:`\varepsilon_{\mathrm{r}}` used when the
+            material has to be created.  Must be positive.
+        padstack_instances : :class:`list` [:class:`PadstackInstance` ], optional
+            Explicit list of via instances to process.  When provided,
+            ``padstack_definition`` and ``nets`` are ignored for filtering.
+        padstack_definition : :class:`str` or :class:`list` [:class:`str` ], optional
+            Pad-stack definition(s) to process.  If omitted, **all** through-hole
+            definitions are considered.
+        dielectric_loss_tangent : :class:`float`, optional
+            Loss tangent :math:`\tan\delta` used when the material has to be
+            created.  Defaults to ``0.0``.
+        nets : :class:`str` or :class:`list` [:class:`str` ], optional
+            Net name(s) used to filter vias.  If omitted, vias belonging to
+            **any** net are processed.
+
+        Returns
+        -------
+        :class:`bool`
+            ``True`` when at least one back-drill was successfully created.
+            ``False`` if no suitable via was found or any error occurred.
+
+        Raises
+        ------
+        ValueError
+            If ``material`` is empty or if ``permittivity`` is non-positive when a
+            new material must be created.
+
+        Notes
+        -----
+        * The routine is safe to call repeatedly: existing back-drills are **not**
+          duplicated because the ``*_BD`` definition name is deterministic.
+        * The original via keeps its pad-stack definition and net assignment; only
+          its unused stub is removed.
+        * The back-drill is **not** subtracted from anti-pads or plane clearances;
+          the filling material is assumed to be electrically invisible at the
+          frequencies of interest.
+
+        Examples
+        --------
+        Create back-drills on all vias belonging to two specific pad-stack
+        definitions and two DDR4 nets:
+
+        >>> edb.padstacks.create_dielectric_filled_backdrills(
+        ...     layer="L3",
+        ...     diameter="0.25mm",
+        ...     material="EPON_827",
+        ...     permittivity=3.8,
+        ...     dielectric_loss_tangent=0.015,
+        ...     padstack_definition=["VIA_10MIL", "VIA_16MIL"],
+        ...     nets=["DDR4_DQ0", "DDR4_DQ1"],
+        ... )
+        True
+        """
+        _padstack_instances = defaultdict(list)
+        if padstack_instances:
+            for inst in padstack_instances:
+                _padstack_instances[inst.padstack_def.name].append(inst)
+        else:
+            if padstack_definition:
+                if isinstance(padstack_definition, str):
+                    padstack_definition = [padstack_definition]
+                padstack_definitions = [
+                    self.definitions.get(padstack_def, None) for padstack_def in padstack_definition
+                ]
+                if nets:
+                    if isinstance(nets, str):
+                        nets = [nets]
+                    for padstack_definition in padstack_definitions:
+                        _padstack_instances[padstack_definition.name] = self.get_instances(
+                            definition_name=padstack_definition.name, net_name=nets
+                        )
+                else:
+                    for padstack_definition in padstack_definitions:
+                        _padstack_instances[padstack_definition.name] = padstack_definition.instances
+            elif nets:
+                instances = self.get_instances(net_name=nets)
+                for inst in instances:
+                    padsatck_def_name = inst.padstack_def.name
+                    padstack_def_layers = inst.padstack_def.data.layer_names
+                    if layer in padstack_def_layers and len(padstack_def_layers) >= 3:
+                        _padstack_instances[padsatck_def_name].append(inst)
+                    else:
+                        self._pedb.logger.info(
+                            f"Drill layer {layer} not in padstack definition layers "
+                            f"or layer number = {len(padstack_def_layers)} "
+                            f"for padstack definition {padsatck_def_name}, skipping for backdrills"
+                        )
+        if not material:
+            raise ValueError("`material` must be specified")
+        if not material in self._pedb.materials:
+            if not dielectric_loss_tangent:
+                dielectric_loss_tangent = 0.0
+            self._pedb.materials.add_dielectric_material(
+                name=material, permittivity=permittivity, dielectric_loss_tangent=dielectric_loss_tangent
+            )
+        for def_name, instances in _padstack_instances.items():
+            padstack_def_backdrill_name = f"{def_name}_BD"
+            start_layer = list(self._pedb.stackup.signal_layers.keys())[-1]  # bottom layer
+            self.create(
+                padstackname=padstack_def_backdrill_name,
+                holediam=self._pedb.value(diameter),
+                paddiam="0.0",
+                antipaddiam="0.0",
+                start_layer=start_layer,
+                stop_layer=layer,
+            )
+            self.definitions[padstack_def_backdrill_name].material = material
+            self.definitions[padstack_def_backdrill_name].hole_plating_ratio = 100.0
+            for inst in instances:
+                inst.set_back_drill_by_layer(drill_to_layer=layer, offset=0.0, diameter=self._pedb.value(diameter))
+                self.place(
+                    position=inst.position,
+                    definition_name=padstack_def_backdrill_name,
+                    fromlayer=start_layer,
+                    tolayer=layer,
+                )
+        return True
 
     def create_circular_padstack(
         self,
@@ -385,10 +564,7 @@ class Padstacks(object):
         Examples
         --------
         >>> via_name = edb_padstacks.create_circular_padstack(
-        ...     padstackname="VIA1",
-        ...     holediam="200um",
-        ...     paddiam="400um",
-        ...     antipaddiam="600um"
+        ...     padstackname="VIA1", holediam="200um", paddiam="400um", antipaddiam="600um"
         ... )
         """
 
@@ -461,6 +637,11 @@ class Padstacks(object):
 
         padstack_def.data = padstack_data
 
+    def delete_batch_instances(self, instances_to_delete):
+        for inst in instances_to_delete:
+            inst._edb_object.delete()
+        self.clear_instances_cache()
+
     def delete_padstack_instances(self, net_names: Union[str, List[str]]) -> bool:
         """Delete padstack instances by net names.
 
@@ -484,8 +665,9 @@ class Padstacks(object):
 
         for p_id, p in self.instances.items():
             if p.net_name in net_names:
-                if not p.delete():  # pragma: no cover
+                if not p._edb_object.delete():  # pragma: no cover
                     return False
+        self.clear_instances_cache()
         return True
 
     def set_solderball(self, padstackInst, sballLayer_name, isTopPlaced=True, ballDiam=100e-6):
@@ -800,7 +982,7 @@ class Padstacks(object):
         if net_list and not isinstance(net_list, list):
             net_list = [net_list]
         via_list = []
-        for inst in self._layout.padstack_instances:
+        for inst_id, inst in self._layout.padstack_instances.items():
             pad_layers_name = inst.padstack_def.data.layer_names
             if len(pad_layers_name) > 1:
                 if not net_list:
@@ -810,6 +992,23 @@ class Padstacks(object):
                         via_list.append(inst)
         return via_list
 
+    def layers_between(self, layers, start_layer=None, stop_layer=None):
+        """
+        Return the sub-list of *layers* that lies between *start_layer*
+        (inclusive) and *stop_layer* (inclusive).  Works no matter which
+        of the two is nearer the top of the stack.
+        """
+        if not layers:
+            return []
+
+        # default to the full stack if one end is unspecified
+        start_idx = layers.index(start_layer) if start_layer in layers else 0
+        stop_idx = layers.index(stop_layer) if stop_layer in layers else len(layers) - 1
+
+        # always slice from the smaller to the larger index
+        lo, hi = sorted((start_idx, stop_idx))
+        return layers[lo : hi + 1]
+
     def create(
         self,
         padstackname: Optional[str] = None,
@@ -951,11 +1150,7 @@ class Padstacks(object):
         else:  # pragma no cover
             self._logger.error("Unknown padstack hole range")
         padstack_data.material = "copper"
-
-        if start_layer and start_layer in layers:  # pragma no cover
-            layers = layers[layers.index(start_layer) :]
-        if stop_layer and stop_layer in layers:  # pragma no cover
-            layers = layers[: layers.index(stop_layer) + 1]
+        layers = self.layers_between(layers=layers, start_layer=start_layer, stop_layer=stop_layer)
         if not isinstance(paddiam, list):
             pad_array = [paddiam]
         else:
@@ -1148,9 +1343,10 @@ class Padstacks(object):
                 layer_map=None,
             )
             padstack_instance.is_layout_pin = is_pin
+            self.clear_instances_cache()
             return PadstackInstance(self._pedb, padstack_instance)
         else:
-            return False
+            raise RuntimeError("Place padstack failed")
 
     def remove_pads_from_padstack(self, padstack_name: str, layer_name: Optional[str] = None):
         """Remove pads from a padstack definition on specified layers.
@@ -1287,12 +1483,34 @@ class Padstacks(object):
         self.definitions[padstack_name].data = new_padstack_def
         return True
 
+    def get_padstack_instance_by_net_name(self, net: str):
+        """Get padstack instances by net name.
+
+        .. deprecated:: 0.55.0
+        Use: :func:`get_instances` with `net_name` parameter instead.
+
+        Parameters
+        ----------
+        net : str
+            Net name to filter padstack instances.
+
+        Returns
+        -------
+        list[:class:`pyedb.grpc.database.primitive.padstack_instance.PadstackInstance`]
+            List of padstack instances associated with the specified net.
+        """
+        warnings.warn(
+            "`get_padstack_instance_by_net_name` is deprecated, use `get_instances` with `net_name` parameter instead.",
+            DeprecationWarning,
+        )
+        return self.get_instances(net_name=net)
+
     def get_instances(
         self,
         name: Optional[str] = None,
         pid: Optional[int] = None,
         definition_name: Optional[str] = None,
-        net_name: Optional[str] = None,
+        net_name: Optional[Union[str, List[str]]] = None,
         component_reference_designator: Optional[str] = None,
         component_pin: Optional[str] = None,
     ) -> List[PadstackInstance]:
@@ -1322,7 +1540,7 @@ class Padstacks(object):
         if pid:
             return instances_by_id[pid]
         elif name:
-            instances = [inst for inst in list(self.instances.values()) if inst.name == name]
+            instances = [inst for inst in list(self.instances.values()) if inst.aedt_name == name]
             if instances:
                 return instances
         else:
@@ -1498,7 +1716,7 @@ class Padstacks(object):
         minimum_via_number: int = 6,
         selected_angles: Optional[List[float]] = None,
         padstack_instances_id: Optional[List[int]] = None,
-    ) -> None:
+    ) -> List[str]:
         """Replace padstack instances along lines into a single polygon.
 
         Detect all pad-stack instances that are placed along lines and replace them by a single polygon based one
@@ -1587,66 +1805,13 @@ class Padstacks(object):
                 inst.delete()
         return instances_created
 
-    def reduce_via_in_bounding_box(self, bounding_box, x_samples, y_samples, nets=None):
-        """Reduces the number of vias intersecting bounding box and nets by x and y samples.
-
-        Parameters
-        ----------
-        bounding_box : tuple or list.
-            bounding box, [x1, y1, x2, y2]
-        x_samples : int
-        y_samples : int
-        nets : str or list, optional
-            net name or list of nets name applying filtering on padstack instances selection. If ``None`` is provided
-            all instances are included in the index. Default value is ``None``.
-
-        Returns
-        -------
-        bool
-            ``True`` when succeeded ``False`` when failed.
-        """
-
-        padstacks_inbox = self.get_padstack_instances_intersecting_bounding_box(bounding_box, nets)
-        if not padstacks_inbox:
-            self._logger.info("no padstack in bounding box")
-            return False
-        else:
-            if len(padstacks_inbox) <= (x_samples * y_samples):
-                self._logger.info(f"more samples {x_samples * y_samples} than existing {len(padstacks_inbox)}")
-                return False
-            else:
-                # extract ids and positions
-                vias = {item: self.instances[item].position for item in padstacks_inbox}
-                ids, positions = zip(*vias.items())
-                pt_x, pt_y = zip(*positions)
-
-                # meshgrid
-                _x_min, _x_max = min(pt_x), max(pt_x)
-                _y_min, _y_max = min(pt_y), max(pt_y)
-
-                x_grid, y_grid = np.meshgrid(
-                    np.linspace(_x_min, _x_max, x_samples), np.linspace(_y_min, _y_max, y_samples)
-                )
-
-                # mapping to meshgrid
-                to_keep = {
-                    ids[np.argmin(np.square(_x - pt_x) + np.square(_y - pt_y))]
-                    for _x, _y in zip(x_grid.ravel(), y_grid.ravel())
-                }
-
-                for item in padstacks_inbox:
-                    if item not in to_keep:
-                        self.instances[item].delete()
-
-                return True
-
     def merge_via(
         self,
         contour_boxes: List[List[float]],
         net_filter: Optional[Union[str, List[str]]] = None,
         start_layer: Optional[str] = None,
         stop_layer: Optional[str] = None,
-    ) -> bool:
+    ) -> List[str]:
         """Evaluate pad-stack instances included on the provided point list and replace all by single instance.
 
         Parameters
@@ -1666,7 +1831,6 @@ class Padstacks(object):
 
         """
 
-        import numpy as np
         from scipy.spatial import ConvexHull
 
         merged_via_ids = []
@@ -1710,6 +1874,7 @@ class Padstacks(object):
             )
             merged_via_ids.append(merged_instance.edb_uid)
             [self.instances[inst].delete() for inst in instances]
+        self.clear_instances_cache()
         return merged_via_ids
 
     def reduce_via_in_bounding_box(
@@ -1765,6 +1930,7 @@ class Padstacks(object):
                 for item in padstacks_inbox:
                     if item not in to_keep:
                         all_instances[item].delete()
+                self.clear_instances_cache()
                 return True
 
     @staticmethod
@@ -1835,3 +2001,90 @@ class Padstacks(object):
             clusters[int(label)].append(padstack_ids[i])
 
         return dict(clusters)
+
+    def reduce_via_by_density(
+        self, padstacks: List[int], cell_size_x: float = 1e-3, cell_size_y: float = 1e-3, delete: bool = False
+    ) -> tuple[List[int], List[List[List[float]]]]:
+        """
+        Reduce the number of vias by density. Keep only one via which is closest to the center of the cell. The cells
+        are automatically populated based on the input vias.
+
+        Parameters
+        ----------
+        padstacks: List[int]
+            List of padstack ids to be reduced.
+
+        cell_size_x : float
+            Width of each grid cell (default is 1e-3).
+
+        cell_size_y : float
+            Height of each grid cell (default is 1e-3).
+
+        delete: bool
+            If True, delete vias that are not kept (default is False).
+
+        Returns
+        -------
+        List[int]
+            IDs of vias kept after reduction.
+
+        List[List[float]]
+            coordinates for grid lines (for plotting).
+
+        """
+        to_keep = set()
+
+        all_instances = self.instances
+        positions = np.array([all_instances[_id].position for _id in padstacks])
+
+        x_coords, y_coords = positions[:, 0], positions[:, 1]
+        x_min, x_max = np.min(x_coords), np.max(x_coords)
+        y_min, y_max = np.min(y_coords), np.max(y_coords)
+
+        padstacks_array = np.array(padstacks)
+        cell_map = {}  # {(cell_x, cell_y): [(id1, [x1, y1]), (id2, [x2, y2), ...]}
+        grid = []
+
+        for idx, pos in enumerate(positions):
+            i = int((pos[0] - x_min) // cell_size_x)
+            j = int((pos[1] - y_min) // cell_size_y)
+            cell_key = (i, j)
+            cell_map.setdefault(cell_key, []).append((padstacks_array[idx], pos))
+
+        for (i, j), items in cell_map.items():
+            # cell center
+            cell_x_min = x_min + i * cell_size_x
+            cell_y_min = y_min + j * cell_size_y
+            cell_x_mid = cell_x_min + 0.5 * cell_size_x
+            cell_y_mid = cell_y_min + 0.5 * cell_size_y
+
+            grid.append(
+                [
+                    [
+                        cell_x_min,
+                        cell_x_min + cell_size_x,
+                        cell_x_min + cell_size_x,
+                        cell_x_min,
+                        cell_x_min,
+                    ],
+                    [
+                        cell_y_min,
+                        cell_y_min,
+                        cell_y_min + cell_size_y,
+                        cell_y_min + cell_size_y,
+                        cell_y_min,
+                    ],
+                ]
+            )
+
+            # Find closest via to cell center
+            distances = [np.linalg.norm(pos - [cell_x_mid, cell_y_mid]) for _, pos in items]
+            closest_idx = np.argmin(distances)
+            to_keep.add(items[closest_idx][0])
+
+        if delete:
+            to_delete = set(padstacks) - to_keep
+            for _id in to_delete:
+                all_instances[_id].delete()
+        self.clear_instances_cache()
+        return list(to_keep), grid
