@@ -1,4 +1,4 @@
-# Copyright (C) 2023 - 2024 ANSYS, Inc. and/or its affiliates.
+# Copyright (C) 2023 - 2025 ANSYS, Inc. and/or its affiliates.
 # SPDX-License-Identifier: MIT
 #
 #
@@ -22,11 +22,13 @@
 
 import math
 import re
+import warnings
 
 from ansys.edb.core.database import ProductIdType as GrpcProductIdType
 from ansys.edb.core.geometry.point_data import PointData as GrpcPointData
 from ansys.edb.core.geometry.polygon_data import PolygonData as GrpcPolygonData
 from ansys.edb.core.hierarchy.pin_group import PinGroup as GrpcPinGroup
+from ansys.edb.core.hierarchy.structure3d import MeshClosure as GrpcMeshClosure, Structure3D as GrpcStructure3D
 from ansys.edb.core.primitive.padstack_instance import (
     PadstackInstance as GrpcPadstackInstance,
 )
@@ -34,7 +36,9 @@ from ansys.edb.core.terminal.pin_group_terminal import (
     PinGroupTerminal as GrpcPinGroupTerminal,
 )
 
+from pyedb.generic.general_methods import generate_unique_name
 from pyedb.grpc.database.definition.padstack_def import PadstackDef
+from pyedb.grpc.database.modeler import Circle
 from pyedb.grpc.database.terminal.padstack_instance_terminal import (
     PadstackInstanceTerminal,
 )
@@ -67,6 +71,16 @@ class PadstackInstance(GrpcPadstackInstance):
         self._pedb = pedb
         self._object_instance = None
 
+    @property
+    def is_pin(self):
+        """Property added for backward compatibility with earlier versions of pyEDB."""
+        return self.is_layout_pin
+
+    @is_pin.setter
+    def is_pin(self, value):
+        """Property added for backward compatibility with earlier versions of pyEDB."""
+        self.is_layout_pin = value
+
     @property
     def definition(self) -> PadstackDef:
         """Padstack definition.
@@ -108,6 +122,117 @@ class PadstackInstance(GrpcPadstackInstance):
             term = PadstackInstanceTerminal(self._pedb, term)
         return term if not term.is_null else None
 
+    @property
+    def side_number(self):
+        """Return the number of sides meshed of the padstack instance.
+        Returns
+        -------
+        int
+            Number of sides meshed of the padstack instance.
+        """
+        side_value = self.get_product_property(GrpcProductIdType.HFSS_3D_LAYOUT, 21)
+        if side_value:
+            return int(re.search(r"(?m)^\s*sid=(\d+)", side_value).group(1))
+        return 0
+
+    @side_number.setter
+    def side_number(self, value):
+        """Set the number of sides meshed of the padstack instance.
+
+        Parameters
+        ----------
+        value : int
+            Number of sides to mesh the padstack instance.
+
+        Returns
+        -------
+        bool
+            True if successful, False otherwise.
+        """
+        if isinstance(value, int) and 3 <= value <= 64:
+            prop_string = f"$begin ''\n\tsid={value}\n\tmat='copper'\n\tvs='Wirebond'\n$end ''\n"
+            self.set_product_property(GrpcProductIdType.HFSS_3D_LAYOUT, 21, prop_string)
+        else:
+            raise ValueError("Number of sides must be an integer between 3 and 64")
+
+    def delete(self):
+        """Delete the padstack instance."""
+        try:
+            self._pedb.padstacks._instances.pop(self.edb_uid, None)
+        except Exception:
+            self._pedb.padstacks.clear_instances_cache()
+        super().delete()
+
+    def set_backdrill_top(self, drill_depth, drill_diameter, offset=0.0):
+        """Set backdrill from top.
+
+        .deprecated:: 0.55.0
+        Use :method:`set_back_drill_by_depth` instead.
+
+        Parameters
+        ----------
+        drill_depth : str
+            Name of the drill to layer.
+        drill_diameter : float, str
+            Diameter of backdrill size.
+        offset : str, optional.
+            offset with respect to the layer to drill to.
+
+        Returns
+        -------
+        bool
+            True if success, False otherwise.
+        """
+        warnings.warn(
+            "`set_backdrill_top` is deprecated. Use `set_back_drill_by_depth` or `set_back_drill_by_layer` instead.",
+            DeprecationWarning,
+        )
+        if isinstance(drill_depth, str):
+            if drill_depth in self._pedb.stackup.layers:
+                return self.set_back_drill_by_layer(
+                    drill_to_layer=self._pedb.stackup.layers[drill_depth],
+                    offset=Value(offset),
+                    diameter=Value(drill_diameter),
+                    from_bottom=False,
+                )
+            else:
+                return self.set_back_drill_by_depth(Value(drill_depth), Value(drill_diameter), from_bottom=False)
+
+    def set_backdrill_bottom(self, drill_depth, drill_diameter, offset=0.0):
+        """Set backdrill from bottom.
+
+        .deprecated: 0.55.0
+        Use: method:`set_back_drill_by_depth` instead.
+
+        Parameters
+        ----------
+        drill_depth : str
+            Name of the drill to layer.
+        drill_diameter : float, str
+            Diameter of backdrill size.
+        offset : str, optional.
+            offset with respect to the layer to drill to.
+
+        Returns
+        -------
+        bool
+            True if success, False otherwise.
+        """
+        warnings.warn(
+            "`set_backdrill_bottom` is deprecated. Use `set_back_drill_by_depth` or `set_back_drill_by_layer` instead.",
+            DeprecationWarning,
+        )
+        if isinstance(drill_depth, str):
+            if drill_depth in self._pedb.stackup.layers:
+                return self.set_back_drill_by_layer(
+                    drill_to_layer=self._pedb.stackup.layers[drill_depth],
+                    offset=Value(offset),
+                    diameter=Value(drill_diameter),
+                    from_bottom=True,
+                )
+            else:
+                return self.set_back_drill_by_depth(Value(drill_depth), Value(drill_diameter), from_bottom=True)
+
     def create_terminal(self, name=None) -> PadstackInstanceTerminal:
         """Create a padstack instance terminal.
 
@@ -322,7 +447,7 @@ class PadstackInstance(GrpcPadstackInstance):
             return self._bounding_box
         return self._bounding_box
 
-    def in_polygon(self, polygon_data, include_partial=True) -> bool:
+    def in_polygon(self, polygon_data, include_partial=True, arbitrary_extent_value=300e-6) -> bool:
         """Check if padstack Instance is in given polygon data.
 
         Parameters
@@ -332,30 +457,35 @@ class PadstackInstance(GrpcPadstackInstance):
             Whether to include partial intersecting instances. The default is ``True``.
         simple_check : bool, optional
             Whether to perform a single check based on the padstack center or check the padstack bounding box.
+        arbitrary_extent_value : float, optional
+            When ``include_partial`` is ``True``, an arbitrary value is used to create a bounding box for the padstack
+            instance to check for intersection and save computation time during the cutout. The default is ``300e-6``.
 
         Returns
         -------
         bool
             ``True`` when successful, ``False`` when failed.
         """
-        int_val = 1 if polygon_data.point_in_polygon(GrpcPointData(self.position)) else 0
+        int_val = 1 if polygon_data.is_inside(GrpcPointData(self.position)) else 0
         if int_val == 0:
+            if include_partial:
+                # pad-stack instance bbox is slow we take an arbitrary value e.g. 300e-6
+                arbitrary_value = arbitrary_extent_value
+                position = self.position
+                inst_bbox = [
+                    position[0] - arbitrary_value / 2,
+                    position[1] - arbitrary_value / 2,
+                    position[0] + arbitrary_value / 2,
+                    position[1] + arbitrary_value / 2,
+                ]
+                int_val = polygon_data.intersection_type(GrpcPolygonData(inst_bbox)).value
+                if int_val == 0:  # fully outside
+                    return False
+                elif int_val in [2, 3]:  # fully or partially inside
+                    return True
             return False
         else:
-            int_val = polygon_data.intersection_type(GrpcPolygonData(self.bounding_box))
-        # Intersection type:
-        # 0 = objects do not intersect
-        # 1 = this object fully inside other (no common contour points)
-        # 2 = other object fully inside this
-        # 3 = common contour points 4 = undefined intersection
-        if int_val == 0:
-            return False
-        elif include_partial:
             return True
-        elif int_val < 3:
-            return True
-        else:
-            return False
 
     @property
     def start_layer(self) -> str:
@@ -500,13 +630,16 @@ class PadstackInstance(GrpcPadstackInstance):
         list
             List of ``[x, y]`` coordinates for the padstack instance position.
         """
-        position = self.get_position_and_rotation()
-        if self.component:
-            out2 = self.component.transform.transform_point(GrpcPointData(position[:2]))
-            self._position = [Value(out2[0]), Value(out2[1])]
-        else:
-            self._position = [Value(pt) for pt in position[:2]]
-        return self._position
+        try:
+            position = self.get_position_and_rotation()
+            if self.component:
+                out2 = self.component.transform.transform_point(GrpcPointData(position[:2]))
+                self._position = [Value(out2[0]), Value(out2[1])]
+            else:
+                self._position = [Value(pt) for pt in position[:2]]
+            return self._position
+        except Exception:
+            return False
 
     @position.setter
     def position(self, value):
@@ -595,6 +728,96 @@ class PadstackInstance(GrpcPadstackInstance):
             except:
                 return False
 
+    @property
+    def backdrill_diameter(self):
+        parameters = []
+        if self.backdrill_bottom:
+            parameters = self.get_back_drill_by_layer(True)
+        elif self.backdrill_top:
+            parameters = self.get_back_drill_by_layer(False)
+        if parameters:
+            return round(parameters[-1].value, 9)
+        return 0.0
+
+    @backdrill_diameter.setter
+    def backdrill_diameter(self, value):
+        if self.backdrill_bottom:
+            parameters = self.get_back_drill_by_layer(True)
+            self.set_back_drill_by_layer(
+                drill_to_layer=parameters[0],
+                offset=parameters[1],
+                diameter=self._pedb.value(value),
+                from_bottom=True,
+            )
+        elif self.backdrill_top:
+            parameters = self.get_back_drill_by_layer(False)
+            self.set_back_drill_by_layer(
+                drill_to_layer=parameters[0],
+                offset=parameters[1],
+                diameter=Value(value),
+                from_bottom=False,
+            )
+
+    @property
+    def backdrill_layer(self):
+        parameters = []
+        if self.backdrill_bottom:
+            parameters = self.get_back_drill_by_layer(True)
+        elif self.backdrill_top:
+            parameters = self.get_back_drill_by_layer(False)
+        if parameters:
+            return parameters[0]
+        return ""
+
+    @backdrill_layer.setter
+    def backdrill_layer(self, value):
+        if self.backdrill_bottom:
+            parameters = self.get_back_drill_by_layer(True)
+            self.set_back_drill_by_layer(
+                drill_to_layer=self._pedb.stackup.layers[value],
+                offset=parameters[1],
+                diameter=parameters[2],
+                from_bottom=True,
+            )
+        elif self.backdrill_top:
+            parameters = self.get_back_drill_by_layer(False)
+            self.set_back_drill_by_layer(
+                drill_to_layer=value,
+                offset=parameters[1],
+                diameter=parameters[2],
+                from_bottom=False,
+            )
+
+    @property
+    def backdrill_offset(self):
+        parameters = []
+        if self.backdrill_bottom:
+            parameters = self.get_back_drill_by_layer(True)
+        elif self.backdrill_top:
+            parameters = self.get_back_drill_by_layer(False)
+        if parameters:
+            return parameters[1].value
+        return 0.0
+
+    @backdrill_offset.setter
+    def backdrill_offset(self, value):
+        if self.backdrill_bottom:
+            parameters = self.get_back_drill_by_layer(True)
+            self.set_back_drill_by_layer(
+                drill_to_layer=parameters[0],
+                offset=Value(value),
+                diameter=parameters[2],
+                from_bottom=True,
+            )
+        elif self.backdrill_top:
+            parameters = self.get_back_drill_by_layer(False)
+            self.set_back_drill_by_layer(
+                drill_to_layer=parameters[0],
+                offset=Value(value),
+                diameter=parameters[2],
+                from_bottom=False,
+            )
+
     @property
     def metal_volume(self) -> float:
         """Metal volume of the via hole instance in cubic units (m3). Metal plating ratio is accounted.
@@ -672,17 +895,84 @@ class PadstackInstance(GrpcPadstackInstance):
     def aedt_name(self, value):
         self.set_product_property(GrpcProductIdType.DESIGNER, 11, value)
 
-    @property
-    def side_number(self) -> int:
-        if not self._side_number:
-            prop_string = "$begin ''\n\tsid=3\n\tmat='copper'\n\tvs='Wirebond'\n$end ''\n"
-            self.set_product_property(GrpcProductIdType.HFSS_3D_LAYOUT, 21, prop_string)
-        self._side_number = self.get_product_property(GrpcProductIdType.HFSS_3D_LAYOUT, 21)
-        return self._side_number
+    def split(self) -> list:
+        """Split padstack instance into multiple instances. The new instances only connect adjacent layers."""
+        pdef_name = self.padstack_definition
+        position = self.position
+        net_name = self.net_name
+        name = self.name
+        stackup_layer_range = list(self._pedb.stackup.signal_layers.keys())
+        start_idx = stackup_layer_range.index(self.start_layer)
+        stop_idx = stackup_layer_range.index(self.stop_layer)
+        temp = []
+        for idx, (l1, l2) in enumerate(
+            list(zip(stackup_layer_range[start_idx:stop_idx], stackup_layer_range[start_idx + 1 : stop_idx + 1]))
+        ):
+            pd_inst = self._pedb.padstacks.place(
+                position, pdef_name, net_name, f"{name}_{idx}", fromlayer=l1, tolayer=l2
+            )
+            temp.append(pd_inst)
+        self.delete()
+        return temp
 
-    @side_number.setter
-    def side_number(self, value):
-        self._side_number = self.set_product_property(GrpcProductIdType.HFSS_3D_LAYOUT, 21, value)
+    def convert_hole_to_conical_shape(self, angle=75):
+        """Convert actual padstack instance to microvias 3D Objects with a given aspect ratio.
+
+        Parameters
+        ----------
+        angle : float, optional
+            Angle of laser penetration in degrees. The angle defines the lowest hole diameter with this formula:
+            HoleDiameter -2*tan(laser_angle* Hole depth). Hole depth is the height of the via (dielectric thickness).
+            The default is ``75``.
+            The lowest hole is ``0.75*HoleDepth/HoleDiam``.
+
+        Returns
+        -------
+        """
+        stackup_layers = self._pedb.stackup.stackup_layers
+        signal_layers = self._pedb.stackup.signal_layers
+        layer_idx = list(signal_layers.keys()).index(self.start_layer)
+
+        _layer_idx = list(stackup_layers.keys()).index(self.start_layer)
+        diel_layer_idx = list(stackup_layers.keys())[_layer_idx + 1]
+        diel_thickness = stackup_layers[diel_layer_idx].thickness
+
+        rad_large = self.definition.hole_diameter / 2
+        rad_small = rad_large - diel_thickness * 1 / math.tan(math.radians(angle))
+
+        if layer_idx + 1 < len(signal_layers) / 2:  # upper half of stack
+            rad_u = rad_large
+            rad_l = rad_small
+        else:
+            rad_u = rad_small
+            rad_l = rad_large
+
+        layout = self._pedb.active_layout
+        cloned_circle = Circle(self._pedb).create(
+            layout=layout,
+            layer=self.start_layer,
+            net=self.net,
+            center_x=Value(self.position[0]),
+            center_y=Value(self.position[1]),
+            radius=Value(rad_u),
+        )
+        cloned_circle2 = Circle(self._pedb).create(
+            layout=layout,
+            layer=self.stop_layer,
+            net=self.net,
+            center_x=Value(self.position[0]),
+            center_y=Value(self.position[1]),
+            radius=Value(rad_l),
+        )
+
+        s3d = GrpcStructure3D.create(layout, generate_unique_name("via3d_" + self.aedt_name.replace("via_", ""), n=3))
+        s3d.add_member(cloned_circle)
+        s3d.add_member(cloned_circle2)
+        s3d.set_material(self.definition.material)
+        s3d.mesh_closure = GrpcMeshClosure.ENDS_CLOSED
+        hole_override_enabled = True
+        hole_override_diam = 0
+        self.set_hole_overrides(hole_override_enabled, Value(hole_override_diam))
 
     def get_backdrill_type(self, from_bottom=True):
         """Return backdrill type
