@@ -1,7 +1,28 @@
+# Copyright (C) 2023 - 2025 ANSYS, Inc. and/or its affiliates.
+# SPDX-License-Identifier: MIT
+#
+#
+# Permission is hereby granted, free of charge, to any person obtaining a copy
+# of this software and associated documentation files (the "Software"), to deal
+# in the Software without restriction, including without limitation the rights
+# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+# copies of the Software, and to permit persons to whom the Software is
+# furnished to do so, subject to the following conditions:
+#
+# The above copyright notice and this permission notice shall be included in all
+# copies or substantial portions of the Software.
+#
+# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+# SOFTWARE.
+
 from ansys.edb.core.database import ProductIdType as GrpcProductIdType
 from ansys.edb.core.utility.value import Value as GrpcValue
 
-import pyedb.siwave_core.cpa.simulation_setup_data_model
 from pyedb.siwave_core.cpa.simulation_setup_data_model import SIwaveCpaSetup, Vrm
 from pyedb.siwave_core.product_properties import SIwaveProperties
 
@@ -190,11 +211,13 @@ class ChannelSetup:
         Raises:
             ValueError: If the input is not a list.
         """
+        from pyedb.siwave_core.cpa.simulation_setup_data_model import Vrm
+
         if not isinstance(value, list):
             raise ValueError("vrm setter must have list as input.")
         vrm_str = ""
         for vrm in value:
-            if isinstance(vrm, pyedb.siwave_core.cpa.simulation_setup_data_model.Vrm):
+            if isinstance(vrm, Vrm):
                 if vrm_str:
                     vrm_str += "*"
                 vrm_str += vrm.name
@@ -757,6 +780,7 @@ class SIWaveCPASimulationSetup:
         self._pedb = pedb
         self._channel_setup = ChannelSetup(pedb)
         self._solver_options = SolverOptions(pedb)
+        self.type = "cpa"
         if isinstance(siwave_cpa_setup_class, SIwaveCpaSetup):
             self._apply_cfg_object(siwave_cpa_setup_class)
         else:
