@@ -1,4 +1,4 @@
-# Copyright (C) 2023 - 2024 ANSYS, Inc. and/or its affiliates.
+# Copyright (C) 2023 - 2025 ANSYS, Inc. and/or its affiliates.
 # SPDX-License-Identifier: MIT
 #
 #
@@ -20,17 +20,34 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 # SOFTWARE.
 
+from __future__ import annotations
+
+from typing import TYPE_CHECKING
+
+if TYPE_CHECKING:
+    from pyedb.grpc.database.primitive.padstack_instance import PadstackInstance
 import re
 
 from ansys.edb.core.terminal.edge_terminal import EdgeType as GrpcEdgeType
-from ansys.edb.core.terminal.terminal import BoundaryType as GrpcBoundaryType
-from ansys.edb.core.terminal.terminal import Terminal as GrpcTerminal
-from ansys.edb.core.terminal.terminal import TerminalType as GrpcTerminalType
+from ansys.edb.core.terminal.terminal import (
+    BoundaryType as GrpcBoundaryType,
+    Terminal as GrpcTerminal,
+    TerminalType as GrpcTerminalType,
+)
 
-from pyedb.grpc.database.primitive.padstack_instance import PadstackInstance
 from pyedb.grpc.database.primitive.primitive import Primitive
 from pyedb.grpc.database.utility.value import Value
 
+mapping_boundary_type = {
+    "port": GrpcBoundaryType.PORT,
+    "dc_terminal": GrpcBoundaryType.DC_TERMINAL,
+    "voltage_probe": GrpcBoundaryType.VOLTAGE_PROBE,
+    "voltage_source": GrpcBoundaryType.VOLTAGE_SOURCE,
+    "current_source": GrpcBoundaryType.CURRENT_SOURCE,
+    "rlc": GrpcBoundaryType.RLC,
+    "pec": GrpcBoundaryType.PEC,
+}
+
 
 class Terminal(GrpcTerminal):
     def __init__(self, pedb, edb_object):
@@ -195,7 +212,11 @@ class Terminal(GrpcTerminal):
 
     @boundary_type.setter
     def boundary_type(self, value):
-        super(Terminal, self.__class__).boundary_type.__set__(self, self._boundary_type_mapping[value])
+        if isinstance(value, str):
+            value = mapping_boundary_type.get(value.lower(), None)
+        if not isinstance(value, GrpcBoundaryType):
+            raise ValueError("Value must be a string or BoundaryType enum.")
+        super(Terminal, self.__class__).boundary_type.__set__(self, value)
 
     @property
     def is_port(self) -> bool:
@@ -243,7 +264,7 @@ class Terminal(GrpcTerminal):
 
     @impedance.setter
     def impedance(self, value):
-        self.impedance = Value(value)
+        super(Terminal, self.__class__).impedance.__set__(self, self._pedb.value(value))
 
     @property
     def reference_object(self) -> any:
@@ -364,13 +385,17 @@ class Terminal(GrpcTerminal):
                     return (primitive, self._pedb)
         return None  # pragma: no cover
 
-    def get_point_terminal_reference_primitive(self) -> Primitive:  # pragma : no cover
-        """Find and return the primitive reference for the point terminal or the padstack instance.
+    def get_point_terminal_reference_primitive(self) -> Primitive:
+        """
+        Find and return the primitive reference for the point terminal or the padstack instance.
 
         Returns
         -------
-        :class:`PadstackInstance <pyedb.grpc.database.primitive.padstack_instance.PadstackInstance>` or
-        :class:`Primitive <pyedb.grpc.database.primitive.primitive.Primitive>`
+        Primitive or PadstackInstance
+            The primitive reference for the point terminal or the padstack instance.
+            Returns an instance of :class:`PadstackInstance
+            <pyedb.grpc.database.primitive.padstack_instance.PadstackInstance>`
+            or :class:`Primitive <pyedb.grpc.database.primitive.primitive.Primitive>`.
         """
 
         ref_term = self.reference_terminal  # return value is type terminal
