@@ -1,3 +1,25 @@
+# Copyright (C) 2023 - 2025 ANSYS, Inc. and/or its affiliates.
+# SPDX-License-Identifier: MIT
+#
+#
+# Permission is hereby granted, free of charge, to any person obtaining a copy
+# of this software and associated documentation files (the "Software"), to deal
+# in the Software without restriction, including without limitation the rights
+# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+# copies of the Software, and to permit persons to whom the Software is
+# furnished to do so, subject to the following conditions:
+#
+# The above copyright notice and this permission notice shall be included in all
+# copies or substantial portions of the Software.
+#
+# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+# SOFTWARE.
+
 """
 This module contains the ``Siwave`` class.
 
@@ -20,8 +42,8 @@ import warnings
 
 from pyedb import Edb
 from pyedb.dotnet.clr_module import _clr
-from pyedb.edb_logger import pyedb_logger
 from pyedb.generic.general_methods import _pythonver, generate_unique_name, is_windows
+from pyedb.generic.settings import settings
 from pyedb.misc.misc import list_installed_ansysem
 from pyedb.siwave_core.icepak import Icepak
 
@@ -110,7 +132,7 @@ class Siwave(object):  # pragma no cover
         return self.version_keys[0]
 
     def __init__(self, specified_version=None):
-        self._logger = pyedb_logger
+        self._logger = settings.logger
         if is_windows:  # pragma: no cover
             modules = [tup[1] for tup in pkgutil.iter_modules()]
             if _clr:
@@ -129,17 +151,15 @@ class Siwave(object):  # pragma no cover
             self._main.AEDTVersion = self._main.oSiwave.GetVersion()[0:6]
             self._main.oSiwave.RestoreWindow()
             specified_version = self.current_version
-            assert specified_version in self.version_keys, "Specified version {} is not known.".format(
-                specified_version
-            )
+            if specified_version not in self.version_keys:
+                raise ValueError("Specified version {} is not known.".format(specified_version))
             version_key = specified_version
             base_path = os.getenv(self._version_ids[specified_version])
             self._main.sDesktopinstallDirectory = base_path
         else:
             if specified_version:
-                assert specified_version in self.version_keys, "Specified version {} is not known.".format(
-                    specified_version
-                )
+                if specified_version not in self.version_keys:
+                    raise ValueError("Specified version {} is not known.".format(specified_version))
                 version_key = specified_version
             else:
                 version_key = self.current_version
